/********************************************************/
/*                 HANTBL.H                             */
/*                                                      */
/*      KS2byte mixture - standard(5601) table          */
/*                                                      */
/*      This tables are represented as a integer        */
/*      array of pairs.                                 */
/*      The first and second part of tables are         */
/*      of single letteres sorted as their order.       */
/*                                                      */
/*              by Cho, Young Hwan.  KAIST, KOREA       */
/*              Email   choyh@csdsun.kaist.kr.ac        */
/*                              4/01/1990               */
/********************************************************/

#define KEY_SIZE        40
#define KSC_SIZE        2350

/*      MAP for KSC2C to KSC2S(KSC-5601)                */
int KSC2C_S[KEY_SIZE][2] = {    
                0xA441, 0xA4BF,         /* k */
                0xA461, 0xA4C0,         /* o */
                0xA4A1, 0xA4C1,         /* i */
                0xA4C1, 0xA4C2,         /* O */
                0xA4E1, 0xA4C3,         /* j */
                0xA521, 0xA4C4,         /* p */
                0xA541, 0xA4C5,         /* u */
                0xA561, 0xA4C6,         /* P */
                0xA5A1, 0xA4C7,         /* h */
                0xA5C1, 0xA4C8,         /* hk */
                0xA5E1, 0xA4C9,         /* ho */
                0xA621, 0xA4CA,         /* hl */
                0xA641, 0xA4CB,         /* y */
                0xA661, 0xA4CC,         /* n */
                0xA6A1, 0xA4CD,         /* nj */
                0xA6C1, 0xA4CE,         /* np */
                0xA6E1, 0xA4CF,         /* nl */
                0xA721, 0xA4D0,         /* b */
                0xA741, 0xA4D1,         /* m */
                0xA761, 0xA4D2,         /* ml */
                0xA7A1, 0xA4D3,         /* l */
                0xAA01, 0xA4A1,         /* r */
                0xAE01, 0xA4A2,         /* R */
                0xB201, 0xA4A4,         /* s */
                0xB601, 0xA4A7,         /* e */
                0xBA01, 0xA4A8,         /* E */
                0xBE01, 0xA4A9,         /* f */
                0xC201, 0xA4B1,         /* a */
                0xC601, 0xA4B2,         /* q */
                0xCA01, 0xA4B3,         /* Q */
                0xCE01, 0xA4B5,         /* t */
                0xD201, 0xA4B6,         /* T */
                0xD601, 0xA4B7,         /* d */
                0xDA01, 0xA4B8,         /* w */
                0xDE01, 0xA4B9,         /* W */
                0xE201, 0xA4BA,         /* c */
                0xE601, 0xA4BB,         /* z */
                0xEA01, 0xA4BC,         /* x */
                0xEE01, 0xA4BD,         /* v */
        };


/*      MAP for KSC2C to KSC2S(KSC-5601)                */
int KSC2S_C[KEY_SIZE][2] = {    
                0xAA01, 0xA4A1,         /* r */
                0xAE01, 0xA4A2,         /* R */
                0xB201, 0xA4A4,         /* s */
                0xB601, 0xA4A7,         /* e */
                0xBA01, 0xA4A8,         /* E */
                0xBE01, 0xA4A9,         /* f */
                0xC201, 0xA4B1,         /* a */
                0xC601, 0xA4B2,         /* q */
                0xCA01, 0xA4B3,         /* Q */
                0xCE01, 0xA4B5,         /* t */
                0xD201, 0xA4B6,         /* T */
                0xD601, 0xA4B7,         /* d */
                0xDA01, 0xA4B8,         /* w */
                0xDE01, 0xA4B9,         /* W */
                0xE201, 0xA4BA,         /* c */
                0xE601, 0xA4BB,         /* z */
                0xEA01, 0xA4BC,         /* x */
                0xEE01, 0xA4BD,         /* v */
                0xA441, 0xA4BF,         /* k */
                0xA461, 0xA4C0,         /* o */
                0xA4A1, 0xA4C1,         /* i */
                0xA4C1, 0xA4C2,         /* O */
                0xA4E1, 0xA4C3,         /* j */
                0xA521, 0xA4C4,         /* p */
                0xA541, 0xA4C5,         /* u */
                0xA561, 0xA4C6,         /* P */
                0xA5A1, 0xA4C7,         /* h */
                0xA5C1, 0xA4C8,         /* hk */
                0xA5E1, 0xA4C9,         /* ho */
                0xA621, 0xA4CA,         /* hl */
                0xA641, 0xA4CB,         /* y */
                0xA661, 0xA4CC,         /* n */
                0xA6A1, 0xA4CD,         /* nj */
                0xA6C1, 0xA4CE,         /* np */
                0xA6E1, 0xA4CF,         /* nl */
                0xA721, 0xA4D0,         /* b */
                0xA741, 0xA4D1,         /* m */
                0xA761, 0xA4D2,         /* ml */
                0xA7A1, 0xA4D3,         /* l */

                };

int KSC2CS[KSC_SIZE][2] = {
                0xA841, 0xB0A1,
                0xA842, 0xB0A2,
                0xA845, 0xB0A3,
                0xA848, 0xB0A4,
                0xA849, 0xB0A5,
                0xA84A, 0xB0A6,
                0xA84B, 0xB0A7,
                0xA851, 0xB0A8,
                0xA852, 0xB0A9,
                0xA853, 0xB0AA,
                0xA854, 0xB0AB,
                0xA855, 0xB0AC,
                0xA856, 0xB0AD,
                0xA857, 0xB0AE,
                0xA858, 0xB0AF,
                0xA85A, 0xB0B0,
                0xA85B, 0xB0B1,
                0xA85C, 0xB0B2,
                0xA861, 0xB0B3,
                0xA862, 0xB0B4,
                0xA865, 0xB0B5,
                0xA869, 0xB0B6,
                0xA871, 0xB0B7,
                0xA872, 0xB0B8,
                0xA874, 0xB0B9,
                0xA875, 0xB0BA,
                0xA876, 0xB0BB,
                0xA8A1, 0xB0BC,
                0xA8A2, 0xB0BD,
                0xA8A5, 0xB0BE,
                0xA8A9, 0xB0BF,
                0xA8B4, 0xB0C0,
                0xA8B6, 0xB0C1,
                0xA8C1, 0xB0C2,
                0xA8C5, 0xB0C3,
                0xA8C9, 0xB0C4,
                0xA8E1, 0xB0C5,
                0xA8E2, 0xB0C6,
                0xA8E5, 0xB0C7,
                0xA8E8, 0xB0C8,
                0xA8E9, 0xB0C9,
                0xA8EB, 0xB0CA,
                0xA8F1, 0xB0CB,
                0xA8F2, 0xB0CC,
                0xA8F4, 0xB0CD,
                0xA8F5, 0xB0CE,
                0xA8F6, 0xB0CF,
                0xA8F7, 0xB0D0,
                0xA8FA, 0xB0D1,
                0xA8FB, 0xB0D2,
                0xA8FC, 0xB0D3,
                0xA921, 0xB0D4,
                0xA925, 0xB0D5,
                0xA929, 0xB0D6,
                0xA931, 0xB0D7,
                0xA932, 0xB0D8,
                0xA934, 0xB0D9,
                0xA935, 0xB0DA,
                0xA936, 0xB0DB,
                0xA941, 0xB0DC,
                0xA942, 0xB0DD,
                0xA943, 0xB0DE,
                0xA945, 0xB0DF,
                0xA948, 0xB0E0,
                0xA949, 0xB0E1,
                0xA951, 0xB0E2,
                0xA952, 0xB0E3,
                0xA954, 0xB0E4,
                0xA955, 0xB0E5,
                0xA956, 0xB0E6,
                0xA95A, 0xB0E7,
                0xA961, 0xB0E8,
                0xA965, 0xB0E9,
                0xA969, 0xB0EA,
                0xA972, 0xB0EB,
                0xA974, 0xB0EC,
                0xA9A1, 0xB0ED,
                0xA9A2, 0xB0EE,
                0xA9A5, 0xB0EF,
                0xA9A8, 0xB0F0,
                0xA9A9, 0xB0F1,
                0xA9AB, 0xB0F2,
                0xA9AD, 0xB0F3,
                0xA9B0, 0xB0F4,
                0xA9B1, 0xB0F5,
                0xA9B2, 0xB0F6,
                0xA9B4, 0xB0F7,
                0xA9B6, 0xB0F8,
                0xA9B7, 0xB0F9,
                0xA9C1, 0xB0FA,
                0xA9C2, 0xB0FB,
                0xA9C5, 0xB0FC,
                0xA9C9, 0xB0FD,
                0xA9CB, 0xB0FE,
                0xA9D1, 0xB1A1,
                0xA9D2, 0xB1A2,
                0xA9D4, 0xB1A3,
                0xA9D6, 0xB1A4,
                0xA9E1, 0xB1A5,
                0xA9E5, 0xB1A6,
                0xA9E9, 0xB1A7,
                0xA9F2, 0xB1A8,
                0xA9F5, 0xB1A9,
                0xA9F6, 0xB1AA,
                0xAA21, 0xB1AB,
                0xAA22, 0xB1AC,
                0xAA25, 0xB1AD,
                0xAA29, 0xB1AE,
                0xAA31, 0xB1AF,
                0xAA32, 0xB1B0,
                0xAA34, 0xB1B1,
                0xAA36, 0xB1B2,
                0xAA41, 0xB1B3,
                0xAA45, 0xB1B4,
                0xAA49, 0xB1B5,
                0xAA52, 0xB1B6,
                0xAA54, 0xB1B7,
                0xAA61, 0xB1B8,
                0xAA62, 0xB1B9,
                0xAA65, 0xB1BA,
                0xAA68, 0xB1BB,
                0xAA69, 0xB1BC,
                0xAA6A, 0xB1BD,
                0xAA6B, 0xB1BE,
                0xAA70, 0xB1BF,
                0xAA71, 0xB1C0,
                0xAA72, 0xB1C1,
                0xAA74, 0xB1C2,
                0xAA76, 0xB1C3,
                0xAA77, 0xB1C4,
                0xAAA1, 0xB1C5,
                0xAAA2, 0xB1C6,
                0xAAA5, 0xB1C7,
                0xAAA9, 0xB1C8,
                0xAAB5, 0xB1C9,
                0xAAB6, 0xB1CA,
                0xAAC1, 0xB1CB,
                0xAAD4, 0xB1CC,
                0xAAE1, 0xB1CD,
                0xAAE2, 0xB1CE,
                0xAAE5, 0xB1CF,
                0xAAE9, 0xB1D0,
                0xAAF1, 0xB1D1,
                0xAAF2, 0xB1D2,
                0xAAF4, 0xB1D3,
                0xAB21, 0xB1D4,
                0xAB25, 0xB1D5,
                0xAB29, 0xB1D6,
                0xAB41, 0xB1D7,
                0xAB42, 0xB1D8,
                0xAB45, 0xB1D9,
                0xAB48, 0xB1DA,
                0xAB49, 0xB1DB,
                0xAB4A, 0xB1DC,
                0xAB51, 0xB1DD,
                0xAB52, 0xB1DE,
                0xAB54, 0xB1DF,
                0xAB56, 0xB1E0,
                0xAB61, 0xB1E1,
                0xABA1, 0xB1E2,
                0xABA2, 0xB1E3,
                0xABA5, 0xB1E4,
                0xABA8, 0xB1E5,
                0xABA9, 0xB1E6,
                0xABAB, 0xB1E7,
                0xABB1, 0xB1E8,
                0xABB2, 0xB1E9,
                0xABB4, 0xB1EA,
                0xABB6, 0xB1EB,
                0xABB7, 0xB1EC,
                0xABBB, 0xB1ED,
                0xAC41, 0xB1EE,
                0xAC42, 0xB1EF,
                0xAC43, 0xB1F0,
                0xAC45, 0xB1F1,
                0xAC49, 0xB1F2,
                0xAC4B, 0xB1F3,
                0xAC51, 0xB1F4,
                0xAC52, 0xB1F5,
                0xAC54, 0xB1F6,
                0xAC55, 0xB1F7,
                0xAC56, 0xB1F8,
                0xAC5A, 0xB1F9,
                0xAC61, 0xB1FA,
                0xAC62, 0xB1FB,
                0xAC65, 0xB1FC,
                0xAC69, 0xB1FD,
                0xAC71, 0xB1FE,
                0xAC72, 0xB2A1,
                0xAC74, 0xB2A2,
                0xAC75, 0xB2A3,
                0xAC76, 0xB2A4,
                0xACA1, 0xB2A5,
                0xACA2, 0xB2A6,
                0xACA9, 0xB2A7,
                0xACE1, 0xB2A8,
                0xACE2, 0xB2A9,
                0xACE3, 0xB2AA,
                0xACE5, 0xB2AB,
                0xACE9, 0xB2AC,
                0xACF1, 0xB2AD,
                0xACF2, 0xB2AE,
                0xACF4, 0xB2AF,
                0xACF5, 0xB2B0,
                0xACF6, 0xB2B1,
                0xAD21, 0xB2B2,
                0xAD22, 0xB2B3,
                0xAD25, 0xB2B4,
                0xAD31, 0xB2B5,
                0xAD34, 0xB2B6,
                0xAD36, 0xB2B7,
                0xAD41, 0xB2B8,
                0xAD45, 0xB2B9,
                0xAD49, 0xB2BA,
                0xAD54, 0xB2BB,
                0xAD55, 0xB2BC,
                0xAD5A, 0xB2BD,
                0xAD61, 0xB2BE,
                0xADA1, 0xB2BF,
                0xADA2, 0xB2C0,
                0xADA5, 0xB2C1,
                0xADA7, 0xB2C2,
                0xADA9, 0xB2C3,
                0xADB1, 0xB2C4,
                0xADB2, 0xB2C5,
                0xADB4, 0xB2C6,
                0xADB6, 0xB2C7,
                0xADB7, 0xB2C8,
                0xADB8, 0xB2C9,
                0xADC1, 0xB2CA,
                0xADC2, 0xB2CB,
                0xADC9, 0xB2CC,
                0xADD5, 0xB2CD,
                0xADD6, 0xB2CE,
                0xADE1, 0xB2CF,
                0xADE2, 0xB2D0,
                0xADF6, 0xB2D1,
                0xAE21, 0xB2D2,
                0xAE25, 0xB2D3,
                0xAE29, 0xB2D4,
                0xAE31, 0xB2D5,
                0xAE32, 0xB2D6,
                0xAE36, 0xB2D7,
                0xAE41, 0xB2D8,
                0xAE61, 0xB2D9,
                0xAE62, 0xB2DA,
                0xAE65, 0xB2DB,
                0xAE69, 0xB2DC,
                0xAE70, 0xB2DD,
                0xAE71, 0xB2DE,
                0xAE72, 0xB2DF,
                0xAE74, 0xB2E0,
                0xAE76, 0xB2E1,
                0xAE77, 0xB2E2,
                0xAEA1, 0xB2E3,
                0xAEA9, 0xB2E4,
                0xAEB5, 0xB2E5,
                0xAEB6, 0xB2E6,
                0xAEC1, 0xB2E7,
                0xAEC2, 0xB2E8,
                0xAEC5, 0xB2E9,
                0xAEC9, 0xB2EA,
                0xAED1, 0xB2EB,
                0xAED2, 0xB2EC,
                0xAED5, 0xB2ED,
                0xAEE1, 0xB2EE,
                0xAEE5, 0xB2EF,
                0xAEE9, 0xB2F0,
                0xAEF1, 0xB2F1,
                0xAEF2, 0xB2F2,
                0xAF21, 0xB2F3,
                0xAF41, 0xB2F4,
                0xAF42, 0xB2F5,
                0xAF45, 0xB2F6,
                0xAF47, 0xB2F7,
                0xAF49, 0xB2F8,
                0xAF4B, 0xB2F9,
                0xAF50, 0xB2FA,
                0xAF51, 0xB2FB,
                0xAF52, 0xB2FC,
                0xAF54, 0xB2FD,
                0xAF56, 0xB2FE,
                0xAF5A, 0xB3A1,
                0xAFA1, 0xB3A2,
                0xAFA2, 0xB3A3,
                0xAFA5, 0xB3A4,
                0xAFA9, 0xB3A5,
                0xAFB1, 0xB3A6,
                0xAFB2, 0xB3A7,
                0xAFB4, 0xB3A8,
                0xAFB6, 0xB3A9,
                0xB041, 0xB3AA,
                0xB042, 0xB3AB,
                0xB043, 0xB3AC,
                0xB045, 0xB3AD,
                0xB048, 0xB3AE,
                0xB049, 0xB3AF,
                0xB04A, 0xB3B0,
                0xB04B, 0xB3B1,
                0xB051, 0xB3B2,
                0xB052, 0xB3B3,
                0xB054, 0xB3B4,
                0xB055, 0xB3B5,
                0xB056, 0xB3B6,
                0xB057, 0xB3B7,
                0xB058, 0xB3B8,
                0xB05A, 0xB3B9,
                0xB05C, 0xB3BA,
                0xB061, 0xB3BB,
                0xB062, 0xB3BC,
                0xB065, 0xB3BD,
                0xB069, 0xB3BE,
                0xB071, 0xB3BF,
                0xB072, 0xB3C0,
                0xB074, 0xB3C1,
                0xB075, 0xB3C2,
                0xB076, 0xB3C3,
                0xB0A1, 0xB3C4,
                0xB0A2, 0xB3C5,
                0xB0A5, 0xB3C6,
                0xB0A9, 0xB3C7,
                0xB0B1, 0xB3C8,
                0xB0B6, 0xB3C9,
                0xB0E1, 0xB3CA,
                0xB0E2, 0xB3CB,
                0xB0E4, 0xB3CC,
                0xB0E5, 0xB3CD,
                0xB0E9, 0xB3CE,
                0xB0EB, 0xB3CF,
                0xB0EC, 0xB3D0,
                0xB0F1, 0xB3D1,
                0xB0F2, 0xB3D2,
                0xB0F4, 0xB3D3,
                0xB0F5, 0xB3D4,
                0xB0F6, 0xB3D5,
                0xB0FC, 0xB3D6,
                0xB121, 0xB3D7,
                0xB122, 0xB3D8,
                0xB125, 0xB3D9,
                0xB129, 0xB3DA,
                0xB131, 0xB3DB,
                0xB132, 0xB3DC,
                0xB134, 0xB3DD,
                0xB135, 0xB3DE,
                0xB136, 0xB3DF,
                0xB141, 0xB3E0,
                0xB142, 0xB3E1,
                0xB145, 0xB3E2,
                0xB149, 0xB3E3,
                0xB151, 0xB3E4,
                0xB152, 0xB3E5,
                0xB155, 0xB3E6,
                0xB156, 0xB3E7,
                0xB159, 0xB3E8,
                0xB161, 0xB3E9,
                0xB165, 0xB3EA,
                0xB1A1, 0xB3EB,
                0xB1A2, 0xB3EC,
                0xB1A5, 0xB3ED,
                0xB1A9, 0xB3EE,
                0xB1AB, 0xB3EF,
                0xB1B1, 0xB3F0,
                0xB1B2, 0xB3F1,
                0xB1B4, 0xB3F2,
                0xB1B6, 0xB3F3,
                0xB1BB, 0xB3F4,
                0xB1BC, 0xB3F5,
                0xB1C1, 0xB3F6,
                0xB1C5, 0xB3F7,
                0xB1C9, 0xB3F8,
                0xB1D5, 0xB3F9,
                0xB221, 0xB3FA,
                0xB225, 0xB3FB,
                0xB229, 0xB3FC,
                0xB231, 0xB3FD,
                0xB232, 0xB3FE,
                0xB234, 0xB4A1,
                0xB241, 0xB4A2,
                0xB242, 0xB4A3,
                0xB245, 0xB4A4,
                0xB249, 0xB4A5,
                0xB252, 0xB4A6,
                0xB254, 0xB4A7,
                0xB256, 0xB4A8,
                0xB261, 0xB4A9,
                0xB262, 0xB4AA,
                0xB265, 0xB4AB,
                0xB268, 0xB4AC,
                0xB269, 0xB4AD,
                0xB271, 0xB4AE,
                0xB272, 0xB4AF,
                0xB274, 0xB4B0,
                0xB276, 0xB4B1,
                0xB2A1, 0xB4B2,
                0xB2B5, 0xB4B3,
                0xB2C1, 0xB4B4,
                0xB2E1, 0xB4B5,
                0xB2E5, 0xB4B6,
                0xB2E9, 0xB4B7,
                0xB2F1, 0xB4B8,
                0xB2F2, 0xB4B9,
                0xB321, 0xB4BA,
                0xB322, 0xB4BB,
                0xB329, 0xB4BC,
                0xB331, 0xB4BD,
                0xB332, 0xB4BE,
                0xB336, 0xB4BF,
                0xB341, 0xB4C0,
                0xB342, 0xB4C1,
                0xB345, 0xB4C2,
                0xB349, 0xB4C3,
                0xB34A, 0xB4C4,
                0xB34B, 0xB4C5,
                0xB351, 0xB4C6,
                0xB352, 0xB4C7,
                0xB354, 0xB4C8,
                0xB356, 0xB4C9,
                0xB357, 0xB4CA,
                0xB35B, 0xB4CB,
                0xB361, 0xB4CC,
                0xB365, 0xB4CD,
                0xB369, 0xB4CE,
                0xB3A1, 0xB4CF,
                0xB3A2, 0xB4D0,
                0xB3A5, 0xB4D1,
                0xB3A9, 0xB4D2,
                0xB3AB, 0xB4D3,
                0xB3B1, 0xB4D4,
                0xB3B2, 0xB4D5,
                0xB3B4, 0xB4D6,
                0xB3B6, 0xB4D7,
                0xB3BB, 0xB4D8,
                0xB441, 0xB4D9,
                0xB442, 0xB4DA,
                0xB443, 0xB4DB,
                0xB445, 0xB4DC,
                0xB448, 0xB4DD,
                0xB449, 0xB4DE,
                0xB44A, 0xB4DF,
                0xB44B, 0xB4E0,
                0xB44C, 0xB4E1,
                0xB450, 0xB4E2,
                0xB451, 0xB4E3,
                0xB452, 0xB4E4,
                0xB454, 0xB4E5,
                0xB455, 0xB4E6,
                0xB456, 0xB4E7,
                0xB457, 0xB4E8,
                0xB458, 0xB4E9,
                0xB45C, 0xB4EA,
                0xB461, 0xB4EB,
                0xB462, 0xB4EC,
                0xB465, 0xB4ED,
                0xB469, 0xB4EE,
                0xB471, 0xB4EF,
                0xB472, 0xB4F0,
                0xB474, 0xB4F1,
                0xB475, 0xB4F2,
                0xB476, 0xB4F3,
                0xB4A1, 0xB4F4,
                0xB4E1, 0xB4F5,
                0xB4E2, 0xB4F6,
                0xB4E3, 0xB4F7,
                0xB4E5, 0xB4F8,
                0xB4E8, 0xB4F9,
                0xB4E9, 0xB4FA,
                0xB4EB, 0xB4FB,
                0xB4EC, 0xB4FC,
                0xB4F1, 0xB4FD,
                0xB4F2, 0xB4FE,
                0xB4F4, 0xB5A1,
                0xB4F6, 0xB5A2,
                0xB4F8, 0xB5A3,
                0xB4FB, 0xB5A4,
                0xB521, 0xB5A5,
                0xB522, 0xB5A6,
                0xB525, 0xB5A7,
                0xB529, 0xB5A8,
                0xB531, 0xB5A9,
                0xB532, 0xB5AA,
                0xB534, 0xB5AB,
                0xB535, 0xB5AC,
                0xB536, 0xB5AD,
                0xB541, 0xB5AE,
                0xB545, 0xB5AF,
                0xB549, 0xB5B0,
                0xB555, 0xB5B1,
                0xB556, 0xB5B2,
                0xB561, 0xB5B3,
                0xB565, 0xB5B4,
                0xB5A1, 0xB5B5,
                0xB5A2, 0xB5B6,
                0xB5A5, 0xB5B7,
                0xB5A8, 0xB5B8,
                0xB5A9, 0xB5B9,
                0xB5AB, 0xB5BA,
                0xB5AD, 0xB5BB,
                0xB5B1, 0xB5BC,
                0xB5B2, 0xB5BD,
                0xB5B4, 0xB5BE,
                0xB5B6, 0xB5BF,
                0xB5B8, 0xB5C0,
                0xB5BA, 0xB5C1,
                0xB5C1, 0xB5C2,
                0xB5C5, 0xB5C3,
                0xB5C9, 0xB5C4,
                0xB5E1, 0xB5C5,
                0xB5F5, 0xB5C6,
                0xB621, 0xB5C7,
                0xB625, 0xB5C8,
                0xB629, 0xB5C9,
                0xB631, 0xB5CA,
                0xB632, 0xB5CB,
                0xB634, 0xB5CC,
                0xB641, 0xB5CD,
                0xB661, 0xB5CE,
                0xB662, 0xB5CF,
                0xB665, 0xB5D0,
                0xB669, 0xB5D1,
                0xB671, 0xB5D2,
                0xB672, 0xB5D3,
                0xB674, 0xB5D4,
                0xB676, 0xB5D5,
                0xB6A1, 0xB5D6,
                0xB6B5, 0xB5D7,
                0xB6C1, 0xB5D8,
                0xB6D6, 0xB5D9,
                0xB6E1, 0xB5DA,
                0xB6E5, 0xB5DB,
                0xB6E9, 0xB5DC,
                0xB6F2, 0xB5DD,
                0xB6F4, 0xB5DE,
                0xB6F6, 0xB5DF,
                0xB721, 0xB5E0,
                0xB725, 0xB5E1,
                0xB729, 0xB5E2,
                0xB731, 0xB5E3,
                0xB736, 0xB5E4,
                0xB741, 0xB5E5,
                0xB742, 0xB5E6,
                0xB745, 0xB5E7,
                0xB748, 0xB5E8,
                0xB749, 0xB5E9,
                0xB74B, 0xB5EA,
                0xB751, 0xB5EB,
                0xB752, 0xB5EC,
                0xB754, 0xB5ED,
                0xB756, 0xB5EE,
                0xB761, 0xB5EF,
                0xB7A1, 0xB5F0,
                0xB7A2, 0xB5F1,
                0xB7A5, 0xB5F2,
                0xB7A8, 0xB5F3,
                0xB7A9, 0xB5F4,
                0xB7B1, 0xB5F5,
                0xB7B2, 0xB5F6,
                0xB7B4, 0xB5F7,
                0xB7B5, 0xB5F8,
                0xB7B6, 0xB5F9,
                0xB7B7, 0xB5FA,
                0xB841, 0xB5FB,
                0xB842, 0xB5FC,
                0xB845, 0xB5FD,
                0xB849, 0xB5FE,
                0xB851, 0xB6A1,
                0xB852, 0xB6A2,
                0xB854, 0xB6A3,
                0xB855, 0xB6A4,
                0xB856, 0xB6A5,
                0xB85C, 0xB6A6,
                0xB861, 0xB6A7,
                0xB862, 0xB6A8,
                0xB865, 0xB6A9,
                0xB869, 0xB6AA,
                0xB871, 0xB6AB,
                0xB872, 0xB6AC,
                0xB874, 0xB6AD,
                0xB875, 0xB6AE,
                0xB876, 0xB6AF,
                0xB8E1, 0xB6B0,
                0xB8E2, 0xB6B1,
                0xB8E5, 0xB6B2,
                0xB8E9, 0xB6B3,
                0xB8EB, 0xB6B4,
                0xB8EC, 0xB6B5,
                0xB8F1, 0xB6B6,
                0xB8F2, 0xB6B7,
                0xB8F4, 0xB6B8,
                0xB8F5, 0xB6B9,
                0xB8F6, 0xB6BA,
                0xB8FC, 0xB6BB,
                0xB921, 0xB6BC,
                0xB922, 0xB6BD,
                0xB925, 0xB6BE,
                0xB929, 0xB6BF,
                0xB931, 0xB6C0,
                0xB932, 0xB6C1,
                0xB934, 0xB6C2,
                0xB935, 0xB6C3,
                0xB936, 0xB6C4,
                0xB941, 0xB6C5,
                0xB955, 0xB6C6,
                0xB9A1, 0xB6C7,
                0xB9A2, 0xB6C8,
                0xB9A5, 0xB6C9,
                0xB9A9, 0xB6CA,
                0xB9B6, 0xB6CB,
                0xB9C1, 0xB6CC,
                0xB9C9, 0xB6CD,
                0xB9E1, 0xB6CE,
                0xBA21, 0xB6CF,
                0xBA25, 0xB6D0,
                0xBA61, 0xB6D1,
                0xBA62, 0xB6D2,
                0xBA65, 0xB6D3,
                0xBA69, 0xB6D4,
                0xBA70, 0xB6D5,
                0xBA71, 0xB6D6,
                0xBA76, 0xB6D7,
                0xBAC1, 0xB6D8,
                0xBAE1, 0xB6D9,
                0xBAE5, 0xB6DA,
                0xBAE9, 0xB6DB,
                0xBAF1, 0xB6DC,
                0xBAF2, 0xB6DD,
                0xBAF6, 0xB6DE,
                0xBB41, 0xB6DF,
                0xBB42, 0xB6E0,
                0xBB45, 0xB6E1,
                0xBB48, 0xB6E2,
                0xBB49, 0xB6E3,
                0xBB51, 0xB6E4,
                0xBB52, 0xB6E5,
                0xBB54, 0xB6E6,
                0xBB61, 0xB6E7,
                0xBB65, 0xB6E8,
                0xBB69, 0xB6E9,
                0xBB71, 0xB6EA,
                0xBB72, 0xB6EB,
                0xBBA1, 0xB6EC,
                0xBBA5, 0xB6ED,
                0xBBA9, 0xB6EE,
                0xBBB1, 0xB6EF,
                0xBBB2, 0xB6F0,
                0xBBB4, 0xB6F1,
                0xBBB6, 0xB6F2,
                0xBC41, 0xB6F3,
                0xBC42, 0xB6F4,
                0xBC45, 0xB6F5,
                0xBC49, 0xB6F6,
                0xBC51, 0xB6F7,
                0xBC52, 0xB6F8,
                0xBC54, 0xB6F9,
                0xBC55, 0xB6FA,
                0xBC56, 0xB6FB,
                0xBC57, 0xB6FC,
                0xBC5B, 0xB6FD,
                0xBC5C, 0xB6FE,
                0xBC61, 0xB7A1,
                0xBC62, 0xB7A2,
                0xBC65, 0xB7A3,
                0xBC69, 0xB7A4,
                0xBC71, 0xB7A5,
                0xBC72, 0xB7A6,
                0xBC74, 0xB7A7,
                0xBC75, 0xB7A8,
                0xBC76, 0xB7A9,
                0xBCA1, 0xB7AA,
                0xBCA2, 0xB7AB,
                0xBCA5, 0xB7AC,
                0xBCB4, 0xB7AD,
                0xBCB6, 0xB7AE,
                0xBCE1, 0xB7AF,
                0xBCE2, 0xB7B0,
                0xBCE5, 0xB7B1,
                0xBCE9, 0xB7B2,
                0xBCF1, 0xB7B3,
                0xBCF2, 0xB7B4,
                0xBCF4, 0xB7B5,
                0xBCF5, 0xB7B6,
                0xBCF6, 0xB7B7,
                0xBCFC, 0xB7B8,
                0xBD21, 0xB7B9,
                0xBD22, 0xB7BA,
                0xBD25, 0xB7BB,
                0xBD29, 0xB7BC,
                0xBD31, 0xB7BD,
                0xBD32, 0xB7BE,
                0xBD34, 0xB7BF,
                0xBD36, 0xB7C0,
                0xBD41, 0xB7C1,
                0xBD42, 0xB7C2,
                0xBD45, 0xB7C3,
                0xBD49, 0xB7C4,
                0xBD51, 0xB7C5,
                0xBD52, 0xB7C6,
                0xBD54, 0xB7C7,
                0xBD55, 0xB7C8,
                0xBD56, 0xB7C9,
                0xBD61, 0xB7CA,
                0xBD65, 0xB7CB,
                0xBD72, 0xB7CC,
                0xBD74, 0xB7CD,
                0xBDA1, 0xB7CE,
                0xBDA2, 0xB7CF,
                0xBDA5, 0xB7D0,
                0xBDA9, 0xB7D1,
                0xBDB1, 0xB7D2,
                0xBDB2, 0xB7D3,
                0xBDB4, 0xB7D4,
                0xBDB6, 0xB7D5,
                0xBDC1, 0xB7D6,
                0xBDC5, 0xB7D7,
                0xBDD6, 0xB7D8,
                0xBDF5, 0xB7D9,
                0xBE21, 0xB7DA,
                0xBE25, 0xB7DB,
                0xBE29, 0xB7DC,
                0xBE31, 0xB7DD,
                0xBE32, 0xB7DE,
                0xBE34, 0xB7DF,
                0xBE36, 0xB7E0,
                0xBE41, 0xB7E1,
                0xBE45, 0xB7E2,
                0xBE49, 0xB7E3,
                0xBE52, 0xB7E4,
                0xBE54, 0xB7E5,
                0xBE56, 0xB7E6,
                0xBE61, 0xB7E7,
                0xBE62, 0xB7E8,
                0xBE65, 0xB7E9,
                0xBE69, 0xB7EA,
                0xBE71, 0xB7EB,
                0xBE72, 0xB7EC,
                0xBE74, 0xB7ED,
                0xBE76, 0xB7EE,
                0xBEA1, 0xB7EF,
                0xBEB5, 0xB7F0,
                0xBEC1, 0xB7F1,
                0xBEE1, 0xB7F2,
                0xBEE2, 0xB7F3,
                0xBEE5, 0xB7F4,
                0xBEE9, 0xB7F5,
                0xBEF1, 0xB7F6,
                0xBEF4, 0xB7F7,
                0xBEF6, 0xB7F8,
                0xBF21, 0xB7F9,
                0xBF22, 0xB7FA,
                0xBF25, 0xB7FB,
                0xBF29, 0xB7FC,
                0xBF31, 0xB7FD,
                0xBF32, 0xB7FE,
                0xBF34, 0xB8A1,
                0xBF36, 0xB8A2,
                0xBF41, 0xB8A3,
                0xBF42, 0xB8A4,
                0xBF45, 0xB8A5,
                0xBF49, 0xB8A6,
                0xBF51, 0xB8A7,
                0xBF52, 0xB8A8,
                0xBF54, 0xB8A9,
                0xBF56, 0xB8AA,
                0xBF57, 0xB8AB,
                0xBF5A, 0xB8AC,
                0xBF5B, 0xB8AD,
                0xBFA1, 0xB8AE,
                0xBFA2, 0xB8AF,
                0xBFA5, 0xB8B0,
                0xBFA9, 0xB8B1,
                0xBFB1, 0xB8B2,
                0xBFB2, 0xB8B3,
                0xBFB4, 0xB8B4,
                0xBFB6, 0xB8B5,
                0xC041, 0xB8B6,
                0xC042, 0xB8B7,
                0xC045, 0xB8B8,
                0xC047, 0xB8B9,
                0xC048, 0xB8BA,
                0xC049, 0xB8BB,
                0xC04A, 0xB8BC,
                0xC04B, 0xB8BD,
                0xC051, 0xB8BE,
                0xC052, 0xB8BF,
                0xC054, 0xB8C0,
                0xC056, 0xB8C1,
                0xC057, 0xB8C2,
                0xC05A, 0xB8C3,
                0xC05C, 0xB8C4,
                0xC061, 0xB8C5,
                0xC062, 0xB8C6,
                0xC065, 0xB8C7,
                0xC069, 0xB8C8,
                0xC071, 0xB8C9,
                0xC072, 0xB8CA,
                0xC074, 0xB8CB,
                0xC075, 0xB8CC,
                0xC076, 0xB8CD,
                0xC077, 0xB8CE,
                0xC0A1, 0xB8CF,
                0xC0A2, 0xB8D0,
                0xC0A9, 0xB8D1,
                0xC0B6, 0xB8D2,
                0xC0E1, 0xB8D3,
                0xC0E2, 0xB8D4,
                0xC0E5, 0xB8D5,
                0xC0E9, 0xB8D6,
                0xC0EB, 0xB8D7,
                0xC0F1, 0xB8D8,
                0xC0F2, 0xB8D9,
                0xC0F4, 0xB8DA,
                0xC0F6, 0xB8DB,
                0xC0F7, 0xB8DC,
                0xC0FC, 0xB8DD,
                0xC121, 0xB8DE,
                0xC122, 0xB8DF,
                0xC125, 0xB8E0,
                0xC129, 0xB8E1,
                0xC131, 0xB8E2,
                0xC132, 0xB8E3,
                0xC134, 0xB8E4,
                0xC135, 0xB8E5,
                0xC136, 0xB8E6,
                0xC141, 0xB8E7,
                0xC142, 0xB8E8,
                0xC145, 0xB8E9,
                0xC149, 0xB8EA,
                0xC154, 0xB8EB,
                0xC155, 0xB8EC,
                0xC156, 0xB8ED,
                0xC158, 0xB8EE,
                0xC161, 0xB8EF,
                0xC1A1, 0xB8F0,
                0xC1A2, 0xB8F1,
                0xC1A4, 0xB8F2,
                0xC1A5, 0xB8F3,
                0xC1A9, 0xB8F4,
                0xC1AB, 0xB8F5,
                0xC1B1, 0xB8F6,
                0xC1B2, 0xB8F7,
                0xC1B4, 0xB8F8,
                0xC1B6, 0xB8F9,
                0xC1C1, 0xB8FA,
                0xC1C5, 0xB8FB,
                0xC1D5, 0xB8FC,
                0xC1D6, 0xB8FD,
                0xC221, 0xB8FE,
                0xC225, 0xB9A1,
                0xC229, 0xB9A2,
                0xC232, 0xB9A3,
                0xC234, 0xB9A4,
                0xC236, 0xB9A5,
                0xC241, 0xB9A6,
                0xC245, 0xB9A7,
                0xC249, 0xB9A8,
                0xC252, 0xB9A9,
                0xC254, 0xB9AA,
                0xC261, 0xB9AB,
                0xC262, 0xB9AC,
                0xC263, 0xB9AD,
                0xC265, 0xB9AE,
                0xC268, 0xB9AF,
                0xC269, 0xB9B0,
                0xC26A, 0xB9B1,
                0xC26B, 0xB9B2,
                0xC271, 0xB9B3,
                0xC272, 0xB9B4,
                0xC274, 0xB9B5,
                0xC276, 0xB9B6,
                0xC27A, 0xB9B7,
                0xC27C, 0xB9B8,
                0xC2A1, 0xB9B9,
                0xC2A5, 0xB9BA,
                0xC2A9, 0xB9BB,
                0xC2B2, 0xB9BC,
                0xC2B4, 0xB9BD,
                0xC2C1, 0xB9BE,
                0xC2E1, 0xB9BF,
                0xC2E5, 0xB9C0,
                0xC2E9, 0xB9C1,
                0xC321, 0xB9C2,
                0xC325, 0xB9C3,
                0xC329, 0xB9C4,
                0xC331, 0xB9C5,
                0xC334, 0xB9C6,
                0xC341, 0xB9C7,
                0xC345, 0xB9C8,
                0xC349, 0xB9C9,
                0xC351, 0xB9CA,
                0xC354, 0xB9CB,
                0xC3A1, 0xB9CC,
                0xC3A2, 0xB9CD,
                0xC3A5, 0xB9CE,
                0xC3A8, 0xB9CF,
                0xC3A9, 0xB9D0,
                0xC3AB, 0xB9D1,
                0xC3B1, 0xB9D2,
                0xC3B2, 0xB9D3,
                0xC3B4, 0xB9D4,
                0xC3B5, 0xB9D5,
                0xC3B6, 0xB9D6,
                0xC3B8, 0xB9D7,
                0xC3BA, 0xB9D8,
                0xC441, 0xB9D9,
                0xC442, 0xB9DA,
                0xC443, 0xB9DB,
                0xC444, 0xB9DC,
                0xC445, 0xB9DD,
                0xC448, 0xB9DE,
                0xC449, 0xB9DF,
                0xC44A, 0xB9E0,
                0xC44B, 0xB9E1,
                0xC44C, 0xB9E2,
                0xC451, 0xB9E3,
                0xC452, 0xB9E4,
                0xC454, 0xB9E5,
                0xC456, 0xB9E6,
                0xC45A, 0xB9E7,
                0xC461, 0xB9E8,
                0xC462, 0xB9E9,
                0xC465, 0xB9EA,
                0xC469, 0xB9EB,
                0xC471, 0xB9EC,
                0xC472, 0xB9ED,
                0xC474, 0xB9EE,
                0xC475, 0xB9EF,
                0xC476, 0xB9F0,
                0xC47A, 0xB9F1,
                0xC4A1, 0xB9F2,
                0xC4A2, 0xB9F3,
                0xC4A5, 0xB9F4,
                0xC4B2, 0xB9F5,
                0xC4E1, 0xB9F6,
                0xC4E2, 0xB9F7,
                0xC4E5, 0xB9F8,
                0xC4E8, 0xB9F9,
                0xC4E9, 0xB9FA,
                0xC4EB, 0xB9FB,
                0xC4F1, 0xB9FC,
                0xC4F2, 0xB9FD,
                0xC4F4, 0xB9FE,
                0xC4F6, 0xBAA1,
                0xC4F7, 0xBAA2,
                0xC521, 0xBAA3,
                0xC522, 0xBAA4,
                0xC525, 0xBAA5,
                0xC528, 0xBAA6,
                0xC529, 0xBAA7,
                0xC531, 0xBAA8,
                0xC532, 0xBAA9,
                0xC534, 0xBAAA,
                0xC535, 0xBAAB,
                0xC536, 0xBAAC,
                0xC541, 0xBAAD,
                0xC542, 0xBAAE,
                0xC545, 0xBAAF,
                0xC549, 0xBAB0,
                0xC552, 0xBAB1,
                0xC554, 0xBAB2,
                0xC555, 0xBAB3,
                0xC556, 0xBAB4,
                0xC55A, 0xBAB5,
                0xC561, 0xBAB6,
                0xC565, 0xBAB7,
                0xC5A1, 0xBAB8,
                0xC5A2, 0xBAB9,
                0xC5A3, 0xBABA,
                0xC5A5, 0xBABB,
                0xC5A9, 0xBABC,
                0xC5B1, 0xBABD,
                0xC5B2, 0xBABE,
                0xC5B4, 0xBABF,
                0xC5B6, 0xBAC0,
                0xC5C1, 0xBAC1,
                0xC5C5, 0xBAC2,
                0xC5D5, 0xBAC3,
                0xC5E1, 0xBAC4,
                0xC5F5, 0xBAC5,
                0xC621, 0xBAC6,
                0xC622, 0xBAC7,
                0xC625, 0xBAC8,
                0xC629, 0xBAC9,
                0xC631, 0xBACA,
                0xC632, 0xBACB,
                0xC641, 0xBACC,
                0xC645, 0xBACD,
                0xC661, 0xBACE,
                0xC662, 0xBACF,
                0xC665, 0xBAD0,
                0xC668, 0xBAD1,
                0xC669, 0xBAD2,
                0xC66A, 0xBAD3,
                0xC66B, 0xBAD4,
                0xC671, 0xBAD5,
                0xC672, 0xBAD6,
                0xC674, 0xBAD7,
                0xC676, 0xBAD8,
                0xC67A, 0xBAD9,
                0xC67B, 0xBADA,
                0xC6A1, 0xBADB,
                0xC6A9, 0xBADC,
                0xC6B5, 0xBADD,
                0xC6C1, 0xBADE,
                0xC6E1, 0xBADF,
                0xC6E2, 0xBAE0,
                0xC6E5, 0xBAE1,
                0xC6E9, 0xBAE2,
                0xC6F6, 0xBAE3,
                0xC721, 0xBAE4,
                0xC725, 0xBAE5,
                0xC729, 0xBAE6,
                0xC731, 0xBAE7,
                0xC734, 0xBAE8,
                0xC736, 0xBAE9,
                0xC741, 0xBAEA,
                0xC742, 0xBAEB,
                0xC745, 0xBAEC,
                0xC749, 0xBAED,
                0xC751, 0xBAEE,
                0xC752, 0xBAEF,
                0xC754, 0xBAF0,
                0xC7A1, 0xBAF1,
                0xC7A2, 0xBAF2,
                0xC7A5, 0xBAF3,
                0xC7A9, 0xBAF4,
                0xC7AB, 0xBAF5,
                0xC7B1, 0xBAF6,
                0xC7B2, 0xBAF7,
                0xC7B4, 0xBAF8,
                0xC7B6, 0xBAF9,
                0xC7B7, 0xBAFA,
                0xC7B8, 0xBAFB,
                0xC841, 0xBAFC,
                0xC842, 0xBAFD,
                0xC845, 0xBAFE,
                0xC849, 0xBBA1,
                0xC84B, 0xBBA2,
                0xC851, 0xBBA3,
                0xC852, 0xBBA4,
                0xC854, 0xBBA5,
                0xC855, 0xBBA6,
                0xC856, 0xBBA7,
                0xC85C, 0xBBA8,
                0xC861, 0xBBA9,
                0xC862, 0xBBAA,
                0xC865, 0xBBAB,
                0xC869, 0xBBAC,
                0xC871, 0xBBAD,
                0xC872, 0xBBAE,
                0xC874, 0xBBAF,
                0xC875, 0xBBB0,
                0xC876, 0xBBB1,
                0xC8A1, 0xBBB2,
                0xC8A2, 0xBBB3,
                0xC8B1, 0xBBB4,
                0xC8E1, 0xBBB5,
                0xC8E2, 0xBBB6,
                0xC8E5, 0xBBB7,
                0xC8E8, 0xBBB8,
                0xC8E9, 0xBBB9,
                0xC8F1, 0xBBBA,
                0xC8F4, 0xBBBB,
                0xC8F5, 0xBBBC,
                0xC8F6, 0xBBBD,
                0xC921, 0xBBBE,
                0xC936, 0xBBBF,
                0xC941, 0xBBC0,
                0xC942, 0xBBC1,
                0xC951, 0xBBC2,
                0xC952, 0xBBC3,
                0xC954, 0xBBC4,
                0xC955, 0xBBC5,
                0xC956, 0xBBC6,
                0xC9A1, 0xBBC7,
                0xC9A2, 0xBBC8,
                0xC9A5, 0xBBC9,
                0xC9A9, 0xBBCA,
                0xC9B1, 0xBBCB,
                0xC9B2, 0xBBCC,
                0xC9B6, 0xBBCD,
                0xCA21, 0xBBCE,
                0xCA41, 0xBBCF,
                0xCA56, 0xBBD0,
                0xCA61, 0xBBD1,
                0xCA62, 0xBBD2,
                0xCA65, 0xBBD3,
                0xCA69, 0xBBD4,
                0xCA71, 0xBBD5,
                0xCA74, 0xBBD6,
                0xCA76, 0xBBD7,
                0xCB21, 0xBBD8,
                0xCB36, 0xBBD9,
                0xCB41, 0xBBDA,
                0xCB45, 0xBBDB,
                0xCB49, 0xBBDC,
                0xCB51, 0xBBDD,
                0xCB52, 0xBBDE,
                0xCBA1, 0xBBDF,
                0xCBA2, 0xBBE0,
                0xCBA5, 0xBBE1,
                0xCBA9, 0xBBE2,
                0xCBB1, 0xBBE3,
                0xCBB2, 0xBBE4,
                0xCBB4, 0xBBE5,
                0xCBB6, 0xBBE6,
                0xCC41, 0xBBE7,
                0xCC42, 0xBBE8,
                0xCC44, 0xBBE9,
                0xCC45, 0xBBEA,
                0xCC48, 0xBBEB,
                0xCC49, 0xBBEC,
                0xCC4A, 0xBBED,
                0xCC4B, 0xBBEE,
                0xCC51, 0xBBEF,
                0xCC52, 0xBBF0,
                0xCC54, 0xBBF1,
                0xCC55, 0xBBF2,
                0xCC56, 0xBBF3,
                0xCC5A, 0xBBF4,
                0xCC61, 0xBBF5,
                0xCC62, 0xBBF6,
                0xCC65, 0xBBF7,
                0xCC69, 0xBBF8,
                0xCC71, 0xBBF9,
                0xCC72, 0xBBFA,
                0xCC74, 0xBBFB,
                0xCC75, 0xBBFC,
                0xCC76, 0xBBFD,
                0xCCA1, 0xBBFE,
                0xCCA2, 0xBCA1,
                0xCCA5, 0xBCA2,
                0xCCA9, 0xBCA3,
                0xCCB1, 0xBCA4,
                0xCCB2, 0xBCA5,
                0xCCB4, 0xBCA6,
                0xCCB6, 0xBCA7,
                0xCCC1, 0xBCA8,
                0xCCC5, 0xBCA9,
                0xCCC9, 0xBCAA,
                0xCCD1, 0xBCAB,
                0xCCD6, 0xBCAC,
                0xCCE1, 0xBCAD,
                0xCCE2, 0xBCAE,
                0xCCE3, 0xBCAF,
                0xCCE4, 0xBCB0,
                0xCCE5, 0xBCB1,
                0xCCE8, 0xBCB2,
                0xCCE9, 0xBCB3,
                0xCCEB, 0xBCB4,
                0xCCEC, 0xBCB5,
                0xCCF1, 0xBCB6,
                0xCCF2, 0xBCB7,
                0xCCF4, 0xBCB8,
                0xCCF5, 0xBCB9,
                0xCCF6, 0xBCBA,
                0xCCFB, 0xBCBB,
                0xCD21, 0xBCBC,
                0xCD22, 0xBCBD,
                0xCD25, 0xBCBE,
                0xCD29, 0xBCBF,
                0xCD31, 0xBCC0,
                0xCD32, 0xBCC1,
                0xCD34, 0xBCC2,
                0xCD35, 0xBCC3,
                0xCD36, 0xBCC4,
                0xCD41, 0xBCC5,
                0xCD42, 0xBCC6,
                0xCD45, 0xBCC7,
                0xCD49, 0xBCC8,
                0xCD51, 0xBCC9,
                0xCD52, 0xBCCA,
                0xCD54, 0xBCCB,
                0xCD55, 0xBCCC,
                0xCD56, 0xBCCD,
                0xCD61, 0xBCCE,
                0xCD65, 0xBCCF,
                0xCD69, 0xBCD0,
                0xCD76, 0xBCD1,
                0xCDA1, 0xBCD2,
                0xCDA2, 0xBCD3,
                0xCDA3, 0xBCD4,
                0xCDA5, 0xBCD5,
                0xCDA9, 0xBCD6,
                0xCDAB, 0xBCD7,
                0xCDB1, 0xBCD8,
                0xCDB2, 0xBCD9,
                0xCDB4, 0xBCDA,
                0xCDB6, 0xBCDB,
                0xCDBA, 0xBCDC,
                0xCDC1, 0xBCDD,
                0xCDC2, 0xBCDE,
                0xCDC5, 0xBCDF,
                0xCDC9, 0xBCE0,
                0xCDD6, 0xBCE1,
                0xCDE1, 0xBCE2,
                0xCDE5, 0xBCE3,
                0xCDE9, 0xBCE4,
                0xCDF1, 0xBCE5,
                0xCDF4, 0xBCE6,
                0xCDF5, 0xBCE7,
                0xCE21, 0xBCE8,
                0xCE25, 0xBCE9,
                0xCE29, 0xBCEA,
                0xCE31, 0xBCEB,
                0xCE32, 0xBCEC,
                0xCE34, 0xBCED,
                0xCE41, 0xBCEE,
                0xCE42, 0xBCEF,
                0xCE45, 0xBCF0,
                0xCE49, 0xBCF1,
                0xCE51, 0xBCF2,
                0xCE52, 0xBCF3,
                0xCE54, 0xBCF4,
                0xCE56, 0xBCF5,
                0xCE61, 0xBCF6,
                0xCE62, 0xBCF7,
                0xCE65, 0xBCF8,
                0xCE68, 0xBCF9,
                0xCE69, 0xBCFA,
                0xCE71, 0xBCFB,
                0xCE72, 0xBCFC,
                0xCE74, 0xBCFD,
                0xCE76, 0xBCFE,
                0xCE78, 0xBDA1,
                0xCE7A, 0xBDA2,
                0xCE7B, 0xBDA3,
                0xCEA1, 0xBDA4,
                0xCEB5, 0xBDA5,
                0xCEC1, 0xBDA6,
                0xCEC2, 0xBDA7,
                0xCEC5, 0xBDA8,
                0xCEC9, 0xBDA9,
                0xCED1, 0xBDAA,
                0xCED6, 0xBDAB,
                0xCEE1, 0xBDAC,
                0xCEE2, 0xBDAD,
                0xCEE5, 0xBDAE,
                0xCEE9, 0xBDAF,
                0xCEF1, 0xBDB0,
                0xCEF2, 0xBDB1,
                0xCEF4, 0xBDB2,
                0xCEF6, 0xBDB3,
                0xCF21, 0xBDB4,
                0xCF22, 0xBDB5,
                0xCF29, 0xBDB6,
                0xCF31, 0xBDB7,
                0xCF34, 0xBDB8,
                0xCF36, 0xBDB9,
                0xCF41, 0xBDBA,
                0xCF42, 0xBDBB,
                0xCF45, 0xBDBC,
                0xCF49, 0xBDBD,
                0xCF4A, 0xBDBE,
                0xCF51, 0xBDBF,
                0xCF52, 0xBDC0,
                0xCF54, 0xBDC1,
                0xCF56, 0xBDC2,
                0xCFA1, 0xBDC3,
                0xCFA2, 0xBDC4,
                0xCFA5, 0xBDC5,
                0xCFA8, 0xBDC6,
                0xCFA9, 0xBDC7,
                0xCFB0, 0xBDC8,
                0xCFB1, 0xBDC9,
                0xCFB2, 0xBDCA,
                0xCFB4, 0xBDCB,
                0xCFB6, 0xBDCC,
                0xCFBB, 0xBDCD,
                0xD041, 0xBDCE,
                0xD042, 0xBDCF,
                0xD044, 0xBDD0,
                0xD045, 0xBDD1,
                0xD049, 0xBDD2,
                0xD051, 0xBDD3,
                0xD052, 0xBDD4,
                0xD055, 0xBDD5,
                0xD056, 0xBDD6,
                0xD05C, 0xBDD7,
                0xD061, 0xBDD8,
                0xD062, 0xBDD9,
                0xD065, 0xBDDA,
                0xD069, 0xBDDB,
                0xD071, 0xBDDC,
                0xD072, 0xBDDD,
                0xD075, 0xBDDE,
                0xD076, 0xBDDF,
                0xD0B6, 0xBDE0,
                0xD0E1, 0xBDE1,
                0xD0E2, 0xBDE2,
                0xD0E5, 0xBDE3,
                0xD0E9, 0xBDE4,
                0xD0EB, 0xBDE5,
                0xD0F1, 0xBDE6,
                0xD0F2, 0xBDE7,
                0xD0F5, 0xBDE8,
                0xD0F6, 0xBDE9,
                0xD121, 0xBDEA,
                0xD125, 0xBDEB,
                0xD129, 0xBDEC,
                0xD165, 0xBDED,
                0xD1A1, 0xBDEE,
                0xD1A2, 0xBDEF,
                0xD1A5, 0xBDF0,
                0xD1A8, 0xBDF1,
                0xD1A9, 0xBDF2,
                0xD1AB, 0xBDF3,
                0xD1B1, 0xBDF4,
                0xD1B2, 0xBDF5,
                0xD1B6, 0xBDF6,
                0xD1C1, 0xBDF7,
                0xD1C2, 0xBDF8,
                0xD1C5, 0xBDF9,
                0xD1D5, 0xBDFA,
                0xD1E1, 0xBDFB,
                0xD1F5, 0xBDFC,
                0xD221, 0xBDFD,
                0xD225, 0xBDFE,
                0xD229, 0xBEA1,
                0xD231, 0xBEA2,
                0xD232, 0xBEA3,
                0xD241, 0xBEA4,
                0xD261, 0xBEA5,
                0xD262, 0xBEA6,
                0xD265, 0xBEA7,
                0xD269, 0xBEA8,
                0xD271, 0xBEA9,
                0xD272, 0xBEAA,
                0xD276, 0xBEAB,
                0xD2A1, 0xBEAC,
                0xD2B5, 0xBEAD,
                0xD2C1, 0xBEAE,
                0xD2E1, 0xBEAF,
                0xD2E5, 0xBEB0,
                0xD336, 0xBEB1,
                0xD341, 0xBEB2,
                0xD342, 0xBEB3,
                0xD345, 0xBEB4,
                0xD349, 0xBEB5,
                0xD34B, 0xBEB6,
                0xD350, 0xBEB7,
                0xD351, 0xBEB8,
                0xD352, 0xBEB9,
                0xD361, 0xBEBA,
                0xD365, 0xBEBB,
                0xD369, 0xBEBC,
                0xD371, 0xBEBD,
                0xD3A1, 0xBEBE,
                0xD3A2, 0xBEBF,
                0xD3A5, 0xBEC0,
                0xD3A9, 0xBEC1,
                0xD3B1, 0xBEC2,
                0xD3B2, 0xBEC3,
                0xD3B4, 0xBEC4,
                0xD3B6, 0xBEC5,
                0xD441, 0xBEC6,
                0xD442, 0xBEC7,
                0xD445, 0xBEC8,
                0xD446, 0xBEC9,
                0xD447, 0xBECA,
                0xD449, 0xBECB,
                0xD44A, 0xBECC,
                0xD44B, 0xBECD,
                0xD450, 0xBECE,
                0xD451, 0xBECF,
                0xD452, 0xBED0,
                0xD454, 0xBED1,
                0xD455, 0xBED2,
                0xD456, 0xBED3,
                0xD45A, 0xBED4,
                0xD45B, 0xBED5,
                0xD461, 0xBED6,
                0xD462, 0xBED7,
                0xD465, 0xBED8,
                0xD469, 0xBED9,
                0xD471, 0xBEDA,
                0xD472, 0xBEDB,
                0xD474, 0xBEDC,
                0xD475, 0xBEDD,
                0xD476, 0xBEDE,
                0xD4A1, 0xBEDF,
                0xD4A2, 0xBEE0,
                0xD4A5, 0xBEE1,
                0xD4A9, 0xBEE2,
                0xD4AC, 0xBEE3,
                0xD4B1, 0xBEE4,
                0xD4B2, 0xBEE5,
                0xD4B4, 0xBEE6,
                0xD4B6, 0xBEE7,
                0xD4BA, 0xBEE8,
                0xD4BC, 0xBEE9,
                0xD4C1, 0xBEEA,
                0xD4C5, 0xBEEB,
                0xD4C9, 0xBEEC,
                0xD4D2, 0xBEED,
                0xD4E1, 0xBEEE,
                0xD4E2, 0xBEEF,
                0xD4E5, 0xBEF0,
                0xD4E6, 0xBEF1,
                0xD4E8, 0xBEF2,
                0xD4E9, 0xBEF3,
                0xD4EA, 0xBEF4,
                0xD4EB, 0xBEF5,
                0xD4F1, 0xBEF6,
                0xD4F2, 0xBEF7,
                0xD4F3, 0xBEF8,
                0xD4F4, 0xBEF9,
                0xD4F5, 0xBEFA,
                0xD4F6, 0xBEFB,
                0xD4F7, 0xBEFC,
                0xD4F9, 0xBEFD,
                0xD4FB, 0xBEFE,
                0xD521, 0xBFA1,
                0xD522, 0xBFA2,
                0xD525, 0xBFA3,
                0xD529, 0xBFA4,
                0xD531, 0xBFA5,
                0xD532, 0xBFA6,
                0xD534, 0xBFA7,
                0xD536, 0xBFA8,
                0xD541, 0xBFA9,
                0xD542, 0xBFAA,
                0xD543, 0xBFAB,
                0xD545, 0xBFAC,
                0xD549, 0xBFAD,
                0xD54B, 0xBFAE,
                0xD54C, 0xBFAF,
                0xD551, 0xBFB0,
                0xD552, 0xBFB1,
                0xD553, 0xBFB2,
                0xD554, 0xBFB3,
                0xD555, 0xBFB4,
                0xD556, 0xBFB5,
                0xD55A, 0xBFB6,
                0xD55B, 0xBFB7,
                0xD55C, 0xBFB8,
                0xD561, 0xBFB9,
                0xD565, 0xBFBA,
                0xD569, 0xBFBB,
                0xD571, 0xBFBC,
                0xD572, 0xBFBD,
                0xD574, 0xBFBE,
                0xD575, 0xBFBF,
                0xD5A1, 0xBFC0,
                0xD5A2, 0xBFC1,
                0xD5A5, 0xBFC2,
                0xD5A9, 0xBFC3,
                0xD5AA, 0xBFC4,
                0xD5AB, 0xBFC5,
                0xD5AD, 0xBFC6,
                0xD5B0, 0xBFC7,
                0xD5B1, 0xBFC8,
                0xD5B2, 0xBFC9,
                0xD5B4, 0xBFCA,
                0xD5B6, 0xBFCB,
                0xD5B8, 0xBFCC,
                0xD5C1, 0xBFCD,
                0xD5C2, 0xBFCE,
                0xD5C5, 0xBFCF,
                0xD5C9, 0xBFD0,
                0xD5D1, 0xBFD1,
                0xD5D2, 0xBFD2,
                0xD5D4, 0xBFD3,
                0xD5D5, 0xBFD4,
                0xD5D6, 0xBFD5,
                0xD5E1, 0xBFD6,
                0xD5E2, 0xBFD7,
                0xD5E5, 0xBFD8,
                0xD5F1, 0xBFD9,
                0xD5F4, 0xBFDA,
                0xD5F6, 0xBFDB,
                0xD621, 0xBFDC,
                0xD622, 0xBFDD,
                0xD625, 0xBFDE,
                0xD629, 0xBFDF,
                0xD631, 0xBFE0,
                0xD632, 0xBFE1,
                0xD634, 0xBFE2,
                0xD636, 0xBFE3,
                0xD641, 0xBFE4,
                0xD642, 0xBFE5,
                0xD645, 0xBFE6,
                0xD649, 0xBFE7,
                0xD651, 0xBFE8,
                0xD652, 0xBFE9,
                0xD654, 0xBFEA,
                0xD656, 0xBFEB,
                0xD661, 0xBFEC,
                0xD662, 0xBFED,
                0xD665, 0xBFEE,
                0xD669, 0xBFEF,
                0xD66A, 0xBFF0,
                0xD66B, 0xBFF1,
                0xD671, 0xBFF2,
                0xD672, 0xBFF3,
                0xD674, 0xBFF4,
                0xD676, 0xBFF5,
                0xD6A1, 0xBFF6,
                0xD6A2, 0xBFF7,
                0xD6A5, 0xBFF8,
                0xD6A9, 0xBFF9,
                0xD6B1, 0xBFFA,
                0xD6B2, 0xBFFB,
                0xD6B5, 0xBFFC,
                0xD6B6, 0xBFFD,
                0xD6C1, 0xBFFE,
                0xD6C2, 0xC0A1,
                0xD6C5, 0xC0A2,
                0xD6C9, 0xC0A3,
                0xD6D1, 0xC0A4,
                0xD6D2, 0xC0A5,
                0xD6D6, 0xC0A6,
                0xD6E1, 0xC0A7,
                0xD6E2, 0xC0A8,
                0xD6E5, 0xC0A9,
                0xD6E9, 0xC0AA,
                0xD6F1, 0xC0AB,
                0xD6F2, 0xC0AC,
                0xD6F4, 0xC0AD,
                0xD6F6, 0xC0AE,
                0xD721, 0xC0AF,
                0xD722, 0xC0B0,
                0xD725, 0xC0B1,
                0xD729, 0xC0B2,
                0xD731, 0xC0B3,
                0xD732, 0xC0B4,
                0xD734, 0xC0B5,
                0xD736, 0xC0B6,
                0xD738, 0xC0B7,
                0xD741, 0xC0B8,
                0xD742, 0xC0B9,
                0xD745, 0xC0BA,
                0xD749, 0xC0BB,
                0xD74F, 0xC0BC,
                0xD751, 0xC0BD,
                0xD752, 0xC0BE,
                0xD754, 0xC0BF,
                0xD756, 0xC0C0,
                0xD757, 0xC0C1,
                0xD758, 0xC0C2,
                0xD759, 0xC0C3,
                0xD75A, 0xC0C4,
                0xD75B, 0xC0C5,
                0xD75C, 0xC0C6,
                0xD761, 0xC0C7,
                0xD765, 0xC0C8,
                0xD769, 0xC0C9,
                0xD771, 0xC0CA,
                0xD774, 0xC0CB,
                0xD7A1, 0xC0CC,
                0xD7A2, 0xC0CD,
                0xD7A5, 0xC0CE,
                0xD7A9, 0xC0CF,
                0xD7AA, 0xC0D0,
                0xD7AB, 0xC0D1,
                0xD7B0, 0xC0D2,
                0xD7B1, 0xC0D3,
                0xD7B2, 0xC0D4,
                0xD7B4, 0xC0D5,
                0xD7B5, 0xC0D6,
                0xD7B6, 0xC0D7,
                0xD7B7, 0xC0D8,
                0xD7BB, 0xC0D9,
                0xD841, 0xC0DA,
                0xD842, 0xC0DB,
                0xD845, 0xC0DC,
                0xD847, 0xC0DD,
                0xD848, 0xC0DE,
                0xD849, 0xC0DF,
                0xD84B, 0xC0E0,
                0xD851, 0xC0E1,
                0xD852, 0xC0E2,
                0xD854, 0xC0E3,
                0xD855, 0xC0E4,
                0xD856, 0xC0E5,
                0xD857, 0xC0E6,
                0xD861, 0xC0E7,
                0xD862, 0xC0E8,
                0xD865, 0xC0E9,
                0xD869, 0xC0EA,
                0xD871, 0xC0EB,
                0xD872, 0xC0EC,
                0xD874, 0xC0ED,
                0xD875, 0xC0EE,
                0xD876, 0xC0EF,
                0xD8A1, 0xC0F0,
                0xD8A2, 0xC0F1,
                0xD8A5, 0xC0F2,
                0xD8A7, 0xC0F3,
                0xD8A9, 0xC0F4,
                0xD8B1, 0xC0F5,
                0xD8B6, 0xC0F6,
                0xD8C1, 0xC0F7,
                0xD8C5, 0xC0F8,
                0xD8C9, 0xC0F9,
                0xD8E1, 0xC0FA,
                0xD8E2, 0xC0FB,
                0xD8E5, 0xC0FC,
                0xD8E9, 0xC0FD,
                0xD8EB, 0xC0FE,
                0xD8F1, 0xC1A1,
                0xD8F2, 0xC1A2,
                0xD8F4, 0xC1A3,
                0xD8F6, 0xC1A4,
                0xD8F7, 0xC1A5,
                0xD921, 0xC1A6,
                0xD922, 0xC1A7,
                0xD925, 0xC1A8,
                0xD929, 0xC1A9,
                0xD931, 0xC1AA,
                0xD932, 0xC1AB,
                0xD934, 0xC1AC,
                0xD936, 0xC1AD,
                0xD941, 0xC1AE,
                0xD945, 0xC1AF,
                0xD949, 0xC1B0,
                0xD951, 0xC1B1,
                0xD952, 0xC1B2,
                0xD955, 0xC1B3,
                0xD956, 0xC1B4,
                0xD961, 0xC1B5,
                0xD9A1, 0xC1B6,
                0xD9A2, 0xC1B7,
                0xD9A5, 0xC1B8,
                0xD9A9, 0xC1B9,
                0xD9AB, 0xC1BA,
                0xD9B1, 0xC1BB,
                0xD9B2, 0xC1BC,
                0xD9B4, 0xC1BD,
                0xD9B6, 0xC1BE,
                0xD9B7, 0xC1BF,
                0xD9B8, 0xC1C0,
                0xD9BC, 0xC1C1,
                0xD9C1, 0xC1C2,
                0xD9C2, 0xC1C3,
                0xD9C9, 0xC1C4,
                0xD9D2, 0xC1C5,
                0xD9D4, 0xC1C6,
                0xD9D6, 0xC1C7,
                0xD9E1, 0xC1C8,
                0xD9F5, 0xC1C9,
                0xD9F6, 0xC1CA,
                0xDA21, 0xC1CB,
                0xDA25, 0xC1CC,
                0xDA29, 0xC1CD,
                0xDA31, 0xC1CE,
                0xDA32, 0xC1CF,
                0xDA34, 0xC1D0,
                0xDA36, 0xC1D1,
                0xDA41, 0xC1D2,
                0xDA42, 0xC1D3,
                0xDA45, 0xC1D4,
                0xDA56, 0xC1D5,
                0xDA61, 0xC1D6,
                0xDA62, 0xC1D7,
                0xDA65, 0xC1D8,
                0xDA69, 0xC1D9,
                0xDA6A, 0xC1DA,
                0xDA6B, 0xC1DB,
                0xDA71, 0xC1DC,
                0xDA72, 0xC1DD,
                0xDA74, 0xC1DE,
                0xDA76, 0xC1DF,
                0xDAA1, 0xC1E0,
                0xDAB5, 0xC1E1,
                0xDAC1, 0xC1E2,
                0xDAE1, 0xC1E3,
                0xDAE2, 0xC1E4,
                0xDAE5, 0xC1E5,
                0xDAE9, 0xC1E6,
                0xDAF1, 0xC1E7,
                0xDAF2, 0xC1E8,
                0xDAF4, 0xC1E9,
                0xDB21, 0xC1EA,
                0xDB25, 0xC1EB,
                0xDB29, 0xC1EC,
                0xDB31, 0xC1ED,
                0xDB41, 0xC1EE,
                0xDB42, 0xC1EF,
                0xDB45, 0xC1F0,
                0xDB49, 0xC1F1,
                0xDB51, 0xC1F2,
                0xDB52, 0xC1F3,
                0xDB54, 0xC1F4,
                0xDB56, 0xC1F5,
                0xDBA1, 0xC1F6,
                0xDBA2, 0xC1F7,
                0xDBA5, 0xC1F8,
                0xDBA8, 0xC1F9,
                0xDBA9, 0xC1FA,
                0xDBAB, 0xC1FB,
                0xDBB1, 0xC1FC,
                0xDBB2, 0xC1FD,
                0xDBB4, 0xC1FE,
                0xDBB6, 0xC2A1,
                0xDBB7, 0xC2A2,
                0xDBBA, 0xC2A3,
                0xDBBB, 0xC2A4,
                0xDC41, 0xC2A5,
                0xDC42, 0xC2A6,
                0xDC45, 0xC2A7,
                0xDC47, 0xC2A8,
                0xDC49, 0xC2A9,
                0xDC4C, 0xC2AA,
                0xDC51, 0xC2AB,
                0xDC52, 0xC2AC,
                0xDC54, 0xC2AD,
                0xDC55, 0xC2AE,
                0xDC56, 0xC2AF,
                0xDC61, 0xC2B0,
                0xDC62, 0xC2B1,
                0xDC65, 0xC2B2,
                0xDC69, 0xC2B3,
                0xDC71, 0xC2B4,
                0xDC72, 0xC2B5,
                0xDC74, 0xC2B6,
                0xDC75, 0xC2B7,
                0xDC76, 0xC2B8,
                0xDCA1, 0xC2B9,
                0xDCA5, 0xC2BA,
                0xDCB6, 0xC2BB,
                0xDCE1, 0xC2BC,
                0xDCE2, 0xC2BD,
                0xDCE5, 0xC2BE,
                0xDCE9, 0xC2BF,
                0xDCF1, 0xC2C0,
                0xDCF2, 0xC2C1,
                0xDCF4, 0xC2C2,
                0xDCF5, 0xC2C3,
                0xDCF6, 0xC2C4,
                0xDD21, 0xC2C5,
                0xDD36, 0xC2C6,
                0xDD41, 0xC2C7,
                0xDD55, 0xC2C8,
                0xDDA1, 0xC2C9,
                0xDDA2, 0xC2CA,
                0xDDA5, 0xC2CB,
                0xDDA9, 0xC2CC,
                0xDDB1, 0xC2CD,
                0xDDB2, 0xC2CE,
                0xDDB4, 0xC2CF,
                0xDDB6, 0xC2D0,
                0xDDB8, 0xC2D1,
                0xDDC1, 0xC2D2,
                0xDDC2, 0xC2D3,
                0xDDC9, 0xC2D4,
                0xDDD5, 0xC2D5,
                0xDDE1, 0xC2D6,
                0xDDF5, 0xC2D7,
                0xDE21, 0xC2D8,
                0xDE25, 0xC2D9,
                0xDE29, 0xC2DA,
                0xDE31, 0xC2DB,
                0xDE32, 0xC2DC,
                0xDE56, 0xC2DD,
                0xDE61, 0xC2DE,
                0xDE62, 0xC2DF,
                0xDE65, 0xC2E0,
                0xDE69, 0xC2E1,
                0xDE71, 0xC2E2,
                0xDE72, 0xC2E3,
                0xDE76, 0xC2E4,
                0xDEA1, 0xC2E5,
                0xDEB5, 0xC2E6,
                0xDEB6, 0xC2E7,
                0xDEE1, 0xC2E8,
                0xDF21, 0xC2E9,
                0xDF41, 0xC2EA,
                0xDF51, 0xC2EB,
                0xDF54, 0xC2EC,
                0xDF56, 0xC2ED,
                0xDFA1, 0xC2EE,
                0xDFA2, 0xC2EF,
                0xDFA5, 0xC2F0,
                0xDFA9, 0xC2F1,
                0xDFB1, 0xC2F2,
                0xDFB2, 0xC2F3,
                0xDFB6, 0xC2F4,
                0xDFB7, 0xC2F5,
                0xDFBC, 0xC2F6,
                0xE041, 0xC2F7,
                0xE042, 0xC2F8,
                0xE045, 0xC2F9,
                0xE047, 0xC2FA,
                0xE049, 0xC2FB,
                0xE051, 0xC2FC,
                0xE052, 0xC2FD,
                0xE054, 0xC2FE,
                0xE055, 0xC3A1,
                0xE056, 0xC3A2,
                0xE057, 0xC3A3,
                0xE061, 0xC3A4,
                0xE062, 0xC3A5,
                0xE065, 0xC3A6,
                0xE069, 0xC3A7,
                0xE071, 0xC3A8,
                0xE072, 0xC3A9,
                0xE074, 0xC3AA,
                0xE075, 0xC3AB,
                0xE076, 0xC3AC,
                0xE0A1, 0xC3AD,
                0xE0A5, 0xC3AE,
                0xE0A7, 0xC3AF,
                0xE0A9, 0xC3B0,
                0xE0B1, 0xC3B1,
                0xE0B6, 0xC3B2,
                0xE0E1, 0xC3B3,
                0xE0E2, 0xC3B4,
                0xE0E5, 0xC3B5,
                0xE0E9, 0xC3B6,
                0xE0F1, 0xC3B7,
                0xE0F2, 0xC3B8,
                0xE0F4, 0xC3B9,
                0xE0F5, 0xC3BA,
                0xE0F6, 0xC3BB,
                0xE121, 0xC3BC,
                0xE122, 0xC3BD,
                0xE125, 0xC3BE,
                0xE129, 0xC3BF,
                0xE131, 0xC3C0,
                0xE132, 0xC3C1,
                0xE134, 0xC3C2,
                0xE136, 0xC3C3,
                0xE141, 0xC3C4,
                0xE145, 0xC3C5,
                0xE155, 0xC3C6,
                0xE161, 0xC3C7,
                0xE165, 0xC3C8,
                0xE176, 0xC3C9,
                0xE1A1, 0xC3CA,
                0xE1A2, 0xC3CB,
                0xE1A5, 0xC3CC,
                0xE1A9, 0xC3CD,
                0xE1B1, 0xC3CE,
                0xE1B2, 0xC3CF,
                0xE1B4, 0xC3D0,
                0xE1B6, 0xC3D1,
                0xE1C1, 0xC3D2,
                0xE1C5, 0xC3D3,
                0xE1C9, 0xC3D4,
                0xE1D6, 0xC3D5,
                0xE221, 0xC3D6,
                0xE225, 0xC3D7,
                0xE229, 0xC3D8,
                0xE231, 0xC3D9,
                0xE232, 0xC3DA,
                0xE234, 0xC3DB,
                0xE236, 0xC3DC,
                0xE241, 0xC3DD,
                0xE251, 0xC3DE,
                0xE261, 0xC3DF,
                0xE262, 0xC3E0,
                0xE265, 0xC3E1,
                0xE269, 0xC3E2,
                0xE271, 0xC3E3,
                0xE272, 0xC3E4,
                0xE274, 0xC3E5,
                0xE276, 0xC3E6,
                0xE2A1, 0xC3E7,
                0xE2B5, 0xC3E8,
                0xE2C1, 0xC3E9,
                0xE2C5, 0xC3EA,
                0xE2E1, 0xC3EB,
                0xE2E5, 0xC3EC,
                0xE2E9, 0xC3ED,
                0xE2F1, 0xC3EE,
                0xE2F2, 0xC3EF,
                0xE2F4, 0xC3F0,
                0xE2F6, 0xC3F1,
                0xE321, 0xC3F2,
                0xE325, 0xC3F3,
                0xE329, 0xC3F4,
                0xE331, 0xC3F5,
                0xE336, 0xC3F6,
                0xE341, 0xC3F7,
                0xE342, 0xC3F8,
                0xE345, 0xC3F9,
                0xE349, 0xC3FA,
                0xE351, 0xC3FB,
                0xE352, 0xC3FC,
                0xE354, 0xC3FD,
                0xE356, 0xC3FE,
                0xE3A1, 0xC4A1,
                0xE3A2, 0xC4A2,
                0xE3A5, 0xC4A3,
                0xE3A8, 0xC4A4,
                0xE3A9, 0xC4A5,
                0xE3AA, 0xC4A6,
                0xE3B1, 0xC4A7,
                0xE3B2, 0xC4A8,
                0xE3B4, 0xC4A9,
                0xE3B6, 0xC4AA,
                0xE441, 0xC4AB,
                0xE442, 0xC4AC,
                0xE445, 0xC4AD,
                0xE449, 0xC4AE,
                0xE451, 0xC4AF,
                0xE452, 0xC4B0,
                0xE454, 0xC4B1,
                0xE456, 0xC4B2,
                0xE461, 0xC4B3,
                0xE462, 0xC4B4,
                0xE465, 0xC4B5,
                0xE469, 0xC4B6,
                0xE471, 0xC4B7,
                0xE472, 0xC4B8,
                0xE474, 0xC4B9,
                0xE475, 0xC4BA,
                0xE476, 0xC4BB,
                0xE4A1, 0xC4BC,
                0xE4A2, 0xC4BD,
                0xE4B6, 0xC4BE,
                0xE4E1, 0xC4BF,
                0xE4E2, 0xC4C0,
                0xE4E5, 0xC4C1,
                0xE4E8, 0xC4C2,
                0xE4E9, 0xC4C3,
                0xE4F1, 0xC4C4,
                0xE4F2, 0xC4C5,
                0xE4F4, 0xC4C6,
                0xE4F5, 0xC4C7,
                0xE4F6, 0xC4C8,
                0xE521, 0xC4C9,
                0xE522, 0xC4CA,
                0xE525, 0xC4CB,
                0xE529, 0xC4CC,
                0xE531, 0xC4CD,
                0xE532, 0xC4CE,
                0xE534, 0xC4CF,
                0xE536, 0xC4D0,
                0xE541, 0xC4D1,
                0xE545, 0xC4D2,
                0xE549, 0xC4D3,
                0xE551, 0xC4D4,
                0xE552, 0xC4D5,
                0xE554, 0xC4D6,
                0xE555, 0xC4D7,
                0xE556, 0xC4D8,
                0xE561, 0xC4D9,
                0xE5A1, 0xC4DA,
                0xE5A2, 0xC4DB,
                0xE5A5, 0xC4DC,
                0xE5A9, 0xC4DD,
                0xE5B1, 0xC4DE,
                0xE5B2, 0xC4DF,
                0xE5B4, 0xC4E0,
                0xE5B6, 0xC4E1,
                0xE5C1, 0xC4E2,
                0xE5C2, 0xC4E3,
                0xE5C5, 0xC4E4,
                0xE5C9, 0xC4E5,
                0xE5D1, 0xC4E6,
                0xE5D6, 0xC4E7,
                0xE5E1, 0xC4E8,
                0xE5F6, 0xC4E9,
                0xE621, 0xC4EA,
                0xE629, 0xC4EB,
                0xE641, 0xC4EC,
                0xE661, 0xC4ED,
                0xE662, 0xC4EE,
                0xE665, 0xC4EF,
                0xE669, 0xC4F0,
                0xE671, 0xC4F1,
                0xE672, 0xC4F2,
                0xE674, 0xC4F3,
                0xE676, 0xC4F4,
                0xE6A1, 0xC4F5,
                0xE6A5, 0xC4F6,
                0xE6A9, 0xC4F7,
                0xE6B6, 0xC4F8,
                0xE6C1, 0xC4F9,
                0xE6D6, 0xC4FA,
                0xE6E1, 0xC4FB,
                0xE6E2, 0xC4FC,
                0xE6E5, 0xC4FD,
                0xE6E9, 0xC4FE,
                0xE6F1, 0xC5A1,
                0xE6F2, 0xC5A2,
                0xE6F4, 0xC5A3,
                0xE6F6, 0xC5A4,
                0xE721, 0xC5A5,
                0xE725, 0xC5A6,
                0xE729, 0xC5A7,
                0xE731, 0xC5A8,
                0xE741, 0xC5A9,
                0xE742, 0xC5AA,
                0xE745, 0xC5AB,
                0xE749, 0xC5AC,
                0xE751, 0xC5AD,
                0xE752, 0xC5AE,
                0xE756, 0xC5AF,
                0xE7A1, 0xC5B0,
                0xE7A2, 0xC5B1,
                0xE7A5, 0xC5B2,
                0xE7A9, 0xC5B3,
                0xE7B1, 0xC5B4,
                0xE7B2, 0xC5B5,
                0xE7B4, 0xC5B6,
                0xE7B6, 0xC5B7,
                0xE841, 0xC5B8,
                0xE842, 0xC5B9,
                0xE845, 0xC5BA,
                0xE849, 0xC5BB,
                0xE84A, 0xC5BC,
                0xE851, 0xC5BD,
                0xE852, 0xC5BE,
                0xE854, 0xC5BF,
                0xE855, 0xC5C0,
                0xE856, 0xC5C1,
                0xE861, 0xC5C2,
                0xE862, 0xC5C3,
                0xE865, 0xC5C4,
                0xE869, 0xC5C5,
                0xE871, 0xC5C6,
                0xE872, 0xC5C7,
                0xE874, 0xC5C8,
                0xE875, 0xC5C9,
                0xE876, 0xC5CA,
                0xE8A1, 0xC5CB,
                0xE8B6, 0xC5CC,
                0xE8E1, 0xC5CD,
                0xE8E2, 0xC5CE,
                0xE8E5, 0xC5CF,
                0xE8E9, 0xC5D0,
                0xE8EB, 0xC5D1,
                0xE8F1, 0xC5D2,
                0xE8F2, 0xC5D3,
                0xE8F4, 0xC5D4,
                0xE8F5, 0xC5D5,
                0xE8F6, 0xC5D6,
                0xE921, 0xC5D7,
                0xE922, 0xC5D8,
                0xE925, 0xC5D9,
                0xE929, 0xC5DA,
                0xE931, 0xC5DB,
                0xE932, 0xC5DC,
                0xE934, 0xC5DD,
                0xE936, 0xC5DE,
                0xE941, 0xC5DF,
                0xE945, 0xC5E0,
                0xE955, 0xC5E1,
                0xE961, 0xC5E2,
                0xE965, 0xC5E3,
                0xE9A1, 0xC5E4,
                0xE9A2, 0xC5E5,
                0xE9A5, 0xC5E6,
                0xE9A9, 0xC5E7,
                0xE9B1, 0xC5E8,
                0xE9B2, 0xC5E9,
                0xE9B4, 0xC5EA,
                0xE9B6, 0xC5EB,
                0xE9BB, 0xC5EC,
                0xE9C1, 0xC5ED,
                0xE9C5, 0xC5EE,
                0xE9E1, 0xC5EF,
                0xEA21, 0xC5F0,
                0xEA25, 0xC5F1,
                0xEA34, 0xC5F2,
                0xEA36, 0xC5F3,
                0xEA41, 0xC5F4,
                0xEA61, 0xC5F5,
                0xEA62, 0xC5F6,
                0xEA65, 0xC5F7,
                0xEA69, 0xC5F8,
                0xEA71, 0xC5F9,
                0xEA72, 0xC5FA,
                0xEA74, 0xC5FB,
                0xEA76, 0xC5FC,
                0xEAA1, 0xC5FD,
                0xEAB5, 0xC5FE,
                0xEAC1, 0xC6A1,
                0xEAE1, 0xC6A2,
                0xEAE2, 0xC6A3,
                0xEAE5, 0xC6A4,
                0xEAE9, 0xC6A5,
                0xEAF1, 0xC6A6,
                0xEAF2, 0xC6A7,
                0xEAF6, 0xC6A8,
                0xEB21, 0xC6A9,
                0xEB25, 0xC6AA,
                0xEB29, 0xC6AB,
                0xEB31, 0xC6AC,
                0xEB36, 0xC6AD,
                0xEB41, 0xC6AE,
                0xEB42, 0xC6AF,
                0xEB45, 0xC6B0,
                0xEB48, 0xC6B1,
                0xEB49, 0xC6B2,
                0xEB4B, 0xC6B3,
                0xEB51, 0xC6B4,
                0xEB52, 0xC6B5,
                0xEB54, 0xC6B6,
                0xEB61, 0xC6B7,
                0xEB65, 0xC6B8,
                0xEB69, 0xC6B9,
                0xEB71, 0xC6BA,
                0xEB72, 0xC6BB,
                0xEBA1, 0xC6BC,
                0xEBA2, 0xC6BD,
                0xEBA5, 0xC6BE,
                0xEBA9, 0xC6BF,
                0xEBB1, 0xC6C0,
                0xEBB2, 0xC6C1,
                0xEBB4, 0xC6C2,
                0xEBB6, 0xC6C3,
                0xEC41, 0xC6C4,
                0xEC42, 0xC6C5,
                0xEC43, 0xC6C6,
                0xEC45, 0xC6C7,
                0xEC49, 0xC6C8,
                0xEC4B, 0xC6C9,
                0xEC51, 0xC6CA,
                0xEC52, 0xC6CB,
                0xEC54, 0xC6CC,
                0xEC55, 0xC6CD,
                0xEC56, 0xC6CE,
                0xEC5A, 0xC6CF,
                0xEC61, 0xC6D0,
                0xEC62, 0xC6D1,
                0xEC65, 0xC6D2,
                0xEC69, 0xC6D3,
                0xEC71, 0xC6D4,
                0xEC72, 0xC6D5,
                0xEC74, 0xC6D6,
                0xEC75, 0xC6D7,
                0xEC76, 0xC6D8,
                0xECA1, 0xC6D9,
                0xECA2, 0xC6DA,
                0xECE1, 0xC6DB,
                0xECE2, 0xC6DC,
                0xECE5, 0xC6DD,
                0xECE9, 0xC6DE,
                0xECF1, 0xC6DF,
                0xECF2, 0xC6E0,
                0xECF4, 0xC6E1,
                0xECF5, 0xC6E2,
                0xECF6, 0xC6E3,
                0xED21, 0xC6E4,
                0xED22, 0xC6E5,
                0xED25, 0xC6E6,
                0xED29, 0xC6E7,
                0xED31, 0xC6E8,
                0xED32, 0xC6E9,
                0xED34, 0xC6EA,
                0xED36, 0xC6EB,
                0xED41, 0xC6EC,
                0xED45, 0xC6ED,
                0xED49, 0xC6EE,
                0xED51, 0xC6EF,
                0xED52, 0xC6F0,
                0xED55, 0xC6F1,
                0xED56, 0xC6F2,
                0xED61, 0xC6F3,
                0xED69, 0xC6F4,
                0xED72, 0xC6F5,
                0xED74, 0xC6F6,
                0xEDA1, 0xC6F7,
                0xEDA2, 0xC6F8,
                0xEDA5, 0xC6F9,
                0xEDA9, 0xC6FA,
                0xEDB1, 0xC6FB,
                0xEDB2, 0xC6FC,
                0xEDB4, 0xC6FD,
                0xEDB6, 0xC6FE,
                0xEDC1, 0xC7A1,
                0xEDD6, 0xC7A2,
                0xEE21, 0xC7A3,
                0xEE25, 0xC7A4,
                0xEE41, 0xC7A5,
                0xEE45, 0xC7A6,
                0xEE49, 0xC7A7,
                0xEE52, 0xC7A8,
                0xEE54, 0xC7A9,
                0xEE61, 0xC7AA,
                0xEE62, 0xC7AB,
                0xEE65, 0xC7AC,
                0xEE68, 0xC7AD,
                0xEE69, 0xC7AE,
                0xEE6B, 0xC7AF,
                0xEE71, 0xC7B0,
                0xEE72, 0xC7B1,
                0xEE74, 0xC7B2,
                0xEE76, 0xC7B3,
                0xEEA1, 0xC7B4,
                0xEEB6, 0xC7B5,
                0xEEE1, 0xC7B6,
                0xEEE5, 0xC7B7,
                0xEEE9, 0xC7B8,
                0xEEF1, 0xC7B9,
                0xEEF4, 0xC7BA,
                0xEF21, 0xC7BB,
                0xEF25, 0xC7BC,
                0xEF29, 0xC7BD,
                0xEF31, 0xC7BE,
                0xEF34, 0xC7BF,
                0xEF36, 0xC7C0,
                0xEF41, 0xC7C1,
                0xEF45, 0xC7C2,
                0xEF49, 0xC7C3,
                0xEF51, 0xC7C4,
                0xEF52, 0xC7C5,
                0xEF54, 0xC7C6,
                0xEFA1, 0xC7C7,
                0xEFA2, 0xC7C8,
                0xEFA5, 0xC7C9,
                0xEFA9, 0xC7CA,
                0xEFB1, 0xC7CB,
                0xEFB2, 0xC7CC,
                0xEFB4, 0xC7CD,
                0xEFB6, 0xC7CE,
                0xF041, 0xC7CF,
                0xF042, 0xC7D0,
                0xF045, 0xC7D1,
                0xF049, 0xC7D2,
                0xF04E, 0xC7D3,
                0xF051, 0xC7D4,
                0xF052, 0xC7D5,
                0xF054, 0xC7D6,
                0xF056, 0xC7D7,
                0xF061, 0xC7D8,
                0xF062, 0xC7D9,
                0xF065, 0xC7DA,
                0xF069, 0xC7DB,
                0xF071, 0xC7DC,
                0xF072, 0xC7DD,
                0xF074, 0xC7DE,
                0xF075, 0xC7DF,
                0xF076, 0xC7E0,
                0xF0A1, 0xC7E1,
                0xF0B6, 0xC7E2,
                0xF0E1, 0xC7E3,
                0xF0E2, 0xC7E4,
                0xF0E5, 0xC7E5,
                0xF0E9, 0xC7E6,
                0xF0EB, 0xC7E7,
                0xF0F1, 0xC7E8,
                0xF0F2, 0xC7E9,
                0xF0F4, 0xC7EA,
                0xF0F6, 0xC7EB,
                0xF121, 0xC7EC,
                0xF122, 0xC7ED,
                0xF125, 0xC7EE,
                0xF129, 0xC7EF,
                0xF131, 0xC7F0,
                0xF132, 0xC7F1,
                0xF134, 0xC7F2,
                0xF136, 0xC7F3,
                0xF141, 0xC7F4,
                0xF142, 0xC7F5,
                0xF145, 0xC7F6,
                0xF149, 0xC7F7,
                0xF151, 0xC7F8,
                0xF152, 0xC7F9,
                0xF154, 0xC7FA,
                0xF155, 0xC7FB,
                0xF156, 0xC7FC,
                0xF161, 0xC7FD,
                0xF165, 0xC7FE,
                0xF169, 0xC8A1,
                0xF172, 0xC8A2,
                0xF1A1, 0xC8A3,
                0xF1A2, 0xC8A4,
                0xF1A5, 0xC8A5,
                0xF1A9, 0xC8A6,
                0xF1AE, 0xC8A7,
                0xF1B1, 0xC8A8,
                0xF1B2, 0xC8A9,
                0xF1B4, 0xC8AA,
                0xF1B6, 0xC8AB,
                0xF1BA, 0xC8AC,
                0xF1C1, 0xC8AD,
                0xF1C2, 0xC8AE,
                0xF1C5, 0xC8AF,
                0xF1C9, 0xC8B0,
                0xF1D4, 0xC8B1,
                0xF1D6, 0xC8B2,
                0xF1E1, 0xC8B3,
                0xF1E2, 0xC8B4,
                0xF1E5, 0xC8B5,
                0xF1F4, 0xC8B6,
                0xF1F6, 0xC8B7,
                0xF221, 0xC8B8,
                0xF222, 0xC8B9,
                0xF225, 0xC8BA,
                0xF229, 0xC8BB,
                0xF232, 0xC8BC,
                0xF234, 0xC8BD,
                0xF236, 0xC8BE,
                0xF241, 0xC8BF,
                0xF245, 0xC8C0,
                0xF249, 0xC8C1,
                0xF252, 0xC8C2,
                0xF254, 0xC8C3,
                0xF261, 0xC8C4,
                0xF262, 0xC8C5,
                0xF265, 0xC8C6,
                0xF269, 0xC8C7,
                0xF26E, 0xC8C8,
                0xF271, 0xC8C9,
                0xF274, 0xC8CA,
                0xF276, 0xC8CB,
                0xF2A1, 0xC8CC,
                0xF2A5, 0xC8CD,
                0xF2A9, 0xC8CE,
                0xF2B1, 0xC8CF,
                0xF2B6, 0xC8D0,
                0xF2C1, 0xC8D1,
                0xF2C2, 0xC8D2,
                0xF2C5, 0xC8D3,
                0xF2C9, 0xC8D4,
                0xF2D6, 0xC8D5,
                0xF2E1, 0xC8D6,
                0xF2E2, 0xC8D7,
                0xF2E5, 0xC8D8,
                0xF2E9, 0xC8D9,
                0xF2F1, 0xC8DA,
                0xF2F2, 0xC8DB,
                0xF2F4, 0xC8DC,
                0xF2F6, 0xC8DD,
                0xF321, 0xC8DE,
                0xF322, 0xC8DF,
                0xF325, 0xC8E0,
                0xF329, 0xC8E1,
                0xF331, 0xC8E2,
                0xF334, 0xC8E3,
                0xF336, 0xC8E4,
                0xF341, 0xC8E5,
                0xF342, 0xC8E6,
                0xF345, 0xC8E7,
                0xF347, 0xC8E8,
                0xF348, 0xC8E9,
                0xF349, 0xC8EA,
                0xF34A, 0xC8EB,
                0xF351, 0xC8EC,
                0xF352, 0xC8ED,
                0xF354, 0xC8EE,
                0xF356, 0xC8EF,
                0xF35A, 0xC8F0,
                0xF361, 0xC8F1,
                0xF365, 0xC8F2,
                0xF369, 0xC8F3,
                0xF371, 0xC8F4,
                0xF372, 0xC8F5,
                0xF376, 0xC8F6,
                0xF3A1, 0xC8F7,
                0xF3A2, 0xC8F8,
                0xF3A5, 0xC8F9,
                0xF3A9, 0xC8FA,
                0xF3B1, 0xC8FB,
                0xF3B2, 0xC8FC,
                0xF3B4, 0xC8FD,
                0xF3B6, 0xC8FE};

/***    end of hantbl.h     ***/
