/*
  modified by DaeGyun Yoon @USC to support SSHR code.
  all the inserted codes are "ifdefed by SSHR2KS".  When compiling without
  SSHR2KS defined, you will have original n2ks program.
  To build sshr2ks you need sshr_scan.l, which converts SSHR code t
  n-byte code.

  	DaeGyun Yoon
	1/19/92
*/
/****************************************************************/
/*              HANGUL AUTOMATA PROGRAM                         */
/*                                                              */
/*      Input : Hangul N-byte code                              */
/*      Output: Hangul StructureRecord                          */
/*                      ksc2s: KSC-5061 Hangul  standard code   */
/*      Access: Interactive Key-in per String                   */
/*                                                              */
/*              Programmed by Cho, Young Hwan. KAIST,KOREA      */
/*                           choyh@csdsun.kaist.ac.kr           */
/*                                            4/7/1990          */
/****************************************************************/

#include <stdio.h>
#include "hantbl.h"             /*      All Tables used for     */

#ifdef SSHR2KS			/* Modified for sshr2ks -DK  */
#ifdef USG
#define rindex strrchr
char *strrchr();
#else
char *rindex ();
#endif

FILE *TmpNbFp;
extern FILE *yyin;
char *ProgName;
#endif /* SSHR2KS */ 


/*     define map to keyboard and KOR-alphabet. */
#define G       65      
#define GG      66
#define G_S     67
#define N       68
#define N_J     69
#define N_H     70
#define D       71
#define DD      72
#define R       73
#define R_G     74
#define R_M     75
#define R_B     76
#define R_S     77
#define R_T     78
#define R_P     79
#define R_H     80
#define M       81
#define B       82
#define BB      83
#define B_S     84
#define S       85
#define SS      86
#define OO      87
#define J       88
#define JJ      89
#define C       90
#define K       91
#define T       92
#define P       93
#define H       94

#define A       98
#define AI      99
#define YA      100
#define YAI     101
#define EO      102
#define E       103
#define YEO     106
#define YE      107
#define O       108
#define O_A     109
#define O_AI    110
#define O_I     111
#define YO      114
#define U       115
#define U_EO    116
#define U_E     117
#define U_I     118
#define YU      119
#define EU      122
#define EU_I    123
#define I       124

/*      Status flag value                               */
#define NONE    0
#define GO_ON   1
#define DONE    2
#define WRONG   3
#define ERROR   4

/*      Define for spacial Character                    */
#define NULL    0
#define ESC     27
#define SPC     ' '
#define EOLN    '\n'

/*      Define for conversion mode                      */
#define KSC     1
#define KSS     2
#define KS3     3
#define KSN     4

/*      State Table for AUTOMATA                        */
int STATE[14][17] = { 
         1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0,  
         1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 4, 5, 6, 7, 8, 0,  
         9,10,11,12,12,12,12,12,12, 0, 0, 0, 8, 0, 8, 0, 0, 
         9,10,11,12,12,12,12,12,12, 0, 0, 0, 0, 8, 8, 0, 0,
         9,10,11,12,12,12,12,12,12, 0, 0, 0, 0, 0, 8, 0, 0,
         9,10,11,12,12,12,12,12,12, 8, 0, 0, 0, 0, 0, 0, 0,
         9,10,11,12,12,12,12,12,12, 0, 8, 0, 0, 0, 0, 0, 0,
         9,10,11,12,12,12,12,12,12, 8, 8, 8, 0, 0, 0, 0, 0,
         9,10,11,12,12,12, 1,12,12, 0, 0, 0, 0, 0, 0, 0, 0,
         1, 1, 1,13, 1, 1, 1, 1, 1, 2, 3, 4, 5, 6, 7, 8, 0, 
         1, 1, 1, 1,13,13, 1, 1, 1, 2, 3, 4, 5, 6, 7, 8, 0, 
        13, 1, 1,13, 1,13, 1,13, 1, 2, 3, 4, 5, 6, 7, 8, 0, 
         1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 4, 5, 6, 7, 8, 0,
         1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 4, 5, 6, 7, 8, 0};

/*      ACTION Table for AUTOMATA                       */
int ACTION[14][17] = {
         0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1,-2,
        12,12,12,12,12,12,12,12,12, 2, 2, 2, 2, 2, 2, 2,-1,
         4, 4, 4, 5, 5, 5, 5, 5, 5,11,11,11, 3,11, 3,11,-1,
         4, 4, 4, 5, 5, 5, 5, 5, 5,11,11,11,11, 3, 3,11,-1,
         4, 4, 4, 5, 5, 5, 5, 5, 5,11,11,11,11,11, 3,11,-1,
         4, 4, 4, 5, 5, 5, 5, 5, 5, 3,11,11,11,11,11,11,-1,
         4, 4, 4, 5, 5, 5, 5, 5, 5,11, 3,11,11,11,11,11,-1,
         4, 4, 4, 5, 5, 5, 5, 5, 5, 3, 3, 3,11,11,11,11,-1,
         4, 4, 4, 5, 5, 5,13, 5, 5,11,11,11,11,11,11,11,-1,
         7, 7, 7, 6, 7, 7, 7, 7, 7, 9, 9, 9, 9, 9, 9, 9,-1, 
         7, 7, 7, 7, 6, 6, 7, 7, 7, 9, 9, 9, 9, 9, 9, 9,-1, 
         6, 7, 7, 6, 7, 6, 7, 6, 7, 9, 9, 9, 9, 9, 9, 9,-1, 
         7, 7, 7, 7, 7, 7, 7, 7, 7, 9, 9, 9, 9, 9, 9, 9,-1, 
         8, 8, 8, 8, 8, 8, 8, 8, 8,10,10,10,10,10,10,10,-1 };

/*      Map for ENG-alphabet to KOR-alphabet            */
int CHO_KSC2C[31] = {      0xa400,0xa800, 0xac00,0xa400,0xb000,0xa400,0xa400, 
      0xb400,0xb800,0xbc00,0xa400,0xa400, 0xa400,0xa400,0xa400,0xa400,0xa400,
      0xc000,0xc400,0xc800,0xa400,0xcc00, 0xd000,0xd400,0xd800,0xdc00,0xe000, 
      0xe400,0xe800,0xec00,0xf000};

int JUNG_KSC2C[28] = {                           0x0020,0x0040,0x0060,0x00a0,
      0x00c0,0x00e0,0x0120,0x0020,0x0020, 0x0140,0x0160,0x01a0,0x01c0,0x01e0,
      0x0220,0x0020,0x0020,0x0240,0x0260, 0x02a0,0x02c0,0x02e0,0x0320,0x0020,
      0x0020,0x0340,0x0360,0x03a0};

int JONG_KSC2C[31] = {     0x0001,0x0002, 0x0003,0x0004,0x0005,0x0006,0x0007,
      0x0008,0x0001,0x0009,0x000a,0x000b, 0x000c,0x000d,0x000e,0x000f,0x0010,
      0x0011,0x0012,0x0001,0x0013,0x0014, 0x0015,0x0016,0x0017,0x0001,0x0018,
      0x0019,0x001a,0x001b,0x001c};

typedef struct hanc_node {
                int flag;
                char cho,jung,jong1,jong2;
        } HANC_TYPE;

HANC_TYPE  Cchar,Nchar;
int   c_state=0,c_act=0,Mode,I_Mode,O_Mode;
char  fn1[20],fn2[20]="conv.out";
FILE  *fp1,*fp2,*fopen();

#ifdef SSHR2KS
main (argc,argv)
int argc;
char *argv[];
#else
main()
#endif /* SSHR2KS */
{ char c;

#ifdef SSHR2KS
  if((ProgName = rindex(*argv,'/')) != NULL)
       ProgName++;
  else
       ProgName = *argv;
  
  yyin = stdin;
  if ( argc > 1) 
       if ((yyin = fopen (argv[1],"r")) == NULL) {
	    fprintf (stderr,"%s:Can't open %s\n",ProgName,argv[1]);
	    exit (-1);
       }
  
  if ((TmpNbFp = tmpfile ()) == NULL) {
       fprintf (stderr, "%s:Can't create Temporary file.\n",ProgName);
       exit (-1);
  }
  
  yylex ();	/* conver sshr to n-byte code */
  rewind (TmpNbFp);
#endif /* SSHR2KS */
	       
        while(1)
          {
#ifdef SSHR2KS
	       c = get_nb_char ();
#else
	        c=getchar();
#endif /* SSHR2KS */
                if(c==EOF) exit(0);
                if(c==14) get_put_hanc();
#ifdef SSHR2KS
                  else    {printf("%c",c);fflush(stdout);}
#else
                  else    printf("%c",c);
#endif 
          }
}


get_put_hanc()
{ char c;

  reset(&Cchar); reset(&Nchar);
#ifdef SSHR2KS
     while ((c = get_nb_char (TmpNbFp)) != EOF)
#else
  while(((c=getchar()) != EOF)) 
#endif /* SSHR2KS */
    {
        into_hanc(c);
        switch(Cchar.flag)  {
           case NONE  : break;
           case GO_ON : printStruct(Cchar); break;
           case DONE  : switch(Nchar.flag) {
                           case GO_ON : case WRONG :
                                printStruct(Cchar); 
                                shift(&Nchar,&Cchar);      break;
                           case NONE  :
                                printStruct(Cchar); shift(&Nchar,&Cchar); break;
                           case ERROR : 
                                printStruct(Cchar); printStruct(Nchar);
                                shift(&Nchar,&Cchar);      Cchar.flag=DONE; 
                                break;
                           }
                        break;
           case WRONG : printStruct(Cchar); shift(&Nchar,&Cchar); break;
           case ERROR : printStruct(Cchar); 
                        if(Nchar.flag==GO_ON) {
                          printStruct(Nchar); shift(&Nchar,&Cchar);}
                        break;
         }
    if(c==15) return;
    }
}

/****   Auotmata and Actions on each state, each type           */
into_hanc(c)
char c;
{  
   char     cho_song,jung_song,jong_song;
   int      CHgroup(),mixVowel(),tmp,intoKsc2c(),intoKsc2s();
 
        c_act  =ACTION[c_state][(tmp=CHgroup(c))];
        c_state= STATE[c_state][tmp];

        switch(c_act)  {
           case -2: /*NON-Hangul or seperator at State0*/
                reset(&Cchar); Cchar.flag=WRONG; Cchar.cho=c;
                reset(&Nchar);
                break;
           case -1: /*NOT-Hangul or seperator*/
                Cchar.flag=DONE;
                reset(&Nchar); Nchar.flag=WRONG;Nchar.cho=c;
                break;
           case 0:/*New Cho-sung*/
                reset(&Cchar); reset(&Nchar);
                Cchar.flag=GO_ON; Cchar.cho=c;
                break;
           case 1:/*New Jung-sung without Cho-sung*/
                Cchar.flag=ERROR; Cchar.cho=NULL; Cchar.jung=c;
                break;
           case 2:/*Cho-sung + New Jung-sung*/
                Cchar.flag=GO_ON; Cchar.jung=c;
                break;
           case 3:/*Cho-Jung-sung + Another Jung-sung*/
                Cchar.flag=GO_ON; Cchar.jung = mixVowel(Cchar.jung,c);
                break;
           case 4:/*Cho-Jung-sung + Jong-sung + (Optional)*/
                Cchar.flag=GO_ON; Cchar.jong1 = c;
                break;
           case 5:/*Cho-Jung-sung + Jong-sung*/
                Cchar.flag=GO_ON;  Cchar.jong1 = c;
                break;
           case 6:/*Cho-Jung-Jong1-sung + Another Jong-sung*/
                Cchar.flag=GO_ON;  Cchar.jong2 = c;
                break;
           case 7:/*Cho-Jung-Jong1-sung + Cho-sung*/
                Cchar.flag=DONE;  Nchar.flag=GO_ON; Nchar.cho=c;
                break;
           case 8:/*Cho-Jung-Jong1-Jong2-sung + Cho-sung*/
                Cchar.flag=DONE;  Nchar.flag=GO_ON; Nchar.cho = c;
                break;
           case 9:/*Cho-Jung-Jong1-sung + Jung-sung*/
                Cchar.flag=DONE; Nchar.flag=GO_ON;
                Nchar.cho = Cchar.jong1; Cchar.jong1=NULL; Nchar.jung =  c; 
                break;
           case 10:/*Cho-Jung-Jong1-Jong2-sung + Jung-sung*/
                Cchar.flag=DONE; Nchar.flag=GO_ON;
                Nchar.cho = Cchar.jong2; Cchar.jong2=NULL; Nchar.jung =  c;
                break;
           case 11:/*Cho-Jung-sung + Errored Jung-sung*/
                Cchar.flag=DONE; Nchar.flag=ERROR; Nchar.jung = c;
                break;
           case 12:/*Cho-sung + Errored Cho-sung*/
                Cchar.flag=ERROR; Nchar.flag=GO_ON; Nchar.cho = c;
                break;
           case 13:/*Cho-Jung-sung + Cho-sung-Only*/
                Cchar.flag=DONE; Nchar.flag=GO_ON; Nchar.cho = c;
                break;
          }
}

/****   Function which make KSC2C code from Hangule-Character   */
int intoKsc2c(c1,c2,c3,c4,res)
char c1,c2,c3,c4;
int  *res;
{  int i1=0xa400,i2=0x0200,i3=0x0001,i4;

   if((c1<G)||(c1>H)) return(-1);
   *res=0;
   i1=CHO_KSC2C[c1-64];
   if((c1!= NULL)&&(i1==0xa400)) return(-1);
   if(c2 != NULL)  i2=JUNG_KSC2C[c2-97];
     else          i2=0x0200;
   if(c3 != NULL)  i3=JONG_KSC2C[mixConso(c3,c4)-64];
     else          i3=0x0001;
   *res=i1^i2^i3;
   return(1);
}

/****   Function which make KSC2S code from Hangule-Character   */
/*      Binary Search algorithm used (Assume ksc2c-ksc2s sorted)*/
int intoKsc2s(key)
int key;
{ int l,u,m,tmp;

        l=0; u= KSC_SIZE -1;
        while(l<=u)
          {   m = (l+u)/2;
              tmp = KSC2CS[m][0];
              if(key  > tmp)  l = m+1;
                else if(key == tmp)  return(KSC2CS[m][1]);
                else if(key  < tmp)  u = m-1;
          }
        l=0; u=KEY_SIZE -1;
        while(l<=u)
          {   m = (l+u)/2;
              tmp = KSC2C_S[m][0];
              if(key  > tmp)  l = m+1;
                else if(key == tmp)  return(KSC2C_S[m][1]);
                else if(key  < tmp)  u = m-1;
           }
        return(-1);
}

/****   Simple StructureRecord Print routine                    */
printStruct(St)
HANC_TYPE St;
{  unsigned int ksc,kss;
   int          hanc;

        if(St.cho == 15) return;
        if((St.flag==DONE)||(St.flag==ERROR)||(St.flag==WRONG))
          { if(intoKsc2c(St.cho,St.jung,St.jong1,St.jong2,&ksc) == -1)
#ifdef SSHR2KS
              { printf("%c",St.cho); fflush(stdout);return; }
#else
              { printf("%c",St.cho); return; }
#endif
            kss=intoKsc2s(ksc);
#ifdef SSHR2KS
	    /* O.K. Let's retry with reasonable  alternative jong-sung. */
	    /* For exampe if someone writes "bok" instead of "bog" we   */
	    /* know this is quite reasonable way of writing.  So we have to */
	    /* make this person happy by correctly recognizing "bok" as */
	    /* "bog" - dkyoon */
	    if(kss == -1) {
		 switch (St.jong1){
		   case K:
		   case G:
		      St.jong1 = G;
		      break;
		   case N:
		      St.jong1 = N;
		      break;
		   case D:
		   case DD:
		   case S:
		   case SS:
		   case J:
		   case JJ:
		   case C:
		   case T:
		      St.jong1 = S;
		      break;
		   case R:
		      St.jong1 = R;
		      break;
		   case M:
		      St.jong1 = M;
		      break;
		   case B:
		   case P:
		      St.jong1 = B;
		      break;
		   default:
		      break;
		 }
		 St.jong2 = NULL;
		 if(intoKsc2c(St.cho,St.jung,St.jong1,St.jong2,&ksc) == -1) {
#ifdef SSHR2KS
		      printf("%c",St.cho); fflush(stdout);return;
#else
		      printf("%c",St.cho); return;
#endif
		 }
		 kss=intoKsc2s(ksc);
	    }
#endif /* SSHR2ks */

            if(kss == -1) return;
#ifdef SSHR2KS
            printf("%c%c",kss>>8,kss&0xff);fflush(stdout);
#else
            printf("%c%c",kss>>8,kss&0xff);
#endif
          }
        return;
}

/****   Reseting into Null StructureRecord routine              */
reset(stru) 
HANC_TYPE *stru;
{       stru->flag=NONE;
        stru->cho=stru->jung=stru->jong1=stru->jong2=NULL;
}

/****   Shifting on two StructureRecord routine                 */
shift(stru2,stru1)
HANC_TYPE *stru1,*stru2;
{       stru1->flag=stru2->flag; stru1->cho=stru2->cho; stru1->jung=stru2->jung;
        stru1->jong1=stru2->jong1; stru1->jong2=stru2->jong2;
        reset(stru2);
}

/****   Hangule Alphabet Grouping for Automata doing well.      */
int CHgroup(c)
char c;
{  int no = 16;
        switch(c)  {
           case  G: case B: no=0; break;
           case  N: no=1; break;
           case  R: no=2; break;
           case  S: no=3; break;
           case  J: no=4; break;
           case  H: no=5; break;
           case DD: case BB: case JJ: no= 6; break;
           case  M: case  T: case  P: no= 7; break;
           case GG: case  D: case SS: case OO: 
           case  C: case K: no= 8; break;
           case  O: no= 9; break;
           case  U: no= 10; break;
           case EU: no= 11; break;
           case  A: case AI: no= 12; break;
           case EO: case  E: no= 13; break;
           case  I: no= 14; break;
           case YA: case YEO: case YU: case YAI: 
           case YE: case YO: no=15; break;
         }
      return(no); 
}

/****   Mixed Vowel combine routine                             */
int mixVowel(c1,c2)
char c1,c2;
{ char c=c1;

     if((c1!=O)&&(c1!=U)&&(c1!=EU)) { c=c1;c1=c2;c2=c;}
     switch(c1)  {
        case O : if(c2==A)  c=O_A; if(c2==AI) c=O_AI; if(c2==I ) c=O_I;
                 break;
        case U : if(c2==EO) c=U_EO; if(c2==E ) c=U_E; if(c2==I ) c=U_I;
                 break;
        case EU: if(c2==I ) c=EU_I;
                 break; }
     return(c);
}

/****   Mixed Consonant combine routine                         */
int mixConso(c1,c2)
char c1,c2;
{ char c=c1;
    switch(c1)  {
       case  G: if(c2==S) c=G_S;
                break;
       case  N: if(c2==J) c=N_J; if(c2==H) c=N_H;
                break;
       case  R: if(c2==G) c=R_G; if(c2==M) c=R_M; if(c2==B) c=R_B;
                if(c2==S) c=R_S; if(c2==T) c=R_T; if(c2==P) c=R_P;
                if(c2==H) c=R_H;
                break;
       case  B: if(c2==S) c=B_S;
                break; }
     return(c);
}


/***  end of n2ks.c ***/
